<?php

$LANG = array(
    'organization' => 'Organizație',
    'name' => 'Nume',
    'website' => 'Site web',
    'work_phone' => 'Telefon',
    'address' => 'Adresă',
    'address1' => 'Strada',
    'address2' => 'Apartament',
    'city' => 'Localitate',
    'state' => 'Județ/Sector',
    'postal_code' => 'Cod poștal',
    'country_id' => 'Țara',
    'contacts' => 'Contacte',
    'first_name' => 'Prenume',
    'last_name' => 'Nume',
    'phone' => 'Telefon',
    'email' => 'Email',
    'additional_info' => 'Informații suplimentare',
    'payment_terms' => 'Termeni de plată',
    'currency_id' => 'Moneda',
    'size_id' => 'Mărime Companie',
    'industry_id' => 'Profil',
    'private_notes' => 'Note particulare',
    'invoice' => 'Factură',
    'client' => 'Client',
    'invoice_date' => 'Data factură',
    'due_date' => 'Scadența',
    'invoice_number' => 'Număr factură',
    'invoice_number_short' => 'Factura #',
    'po_number' => 'Ordin de cumpărare nr',
    'po_number_short' => 'Nr. ordin',
    'frequency_id' => 'Cât de des',
    'discount' => 'Discount',
    'taxes' => 'Taxe',
    'tax' => 'Taxă',
    'item' => 'Element',
    'description' => 'Descriere',
    'unit_cost' => 'Preț unitar',
    'quantity' => 'Cantitate',
    'line_total' => 'Total linie',
    'subtotal' => 'Subtotal',
    'paid_to_date' => 'Plătit Pâna Acum',
    'balance_due' => 'Total De Plată',
    'invoice_design_id' => 'Model',
    'terms' => 'Termeni',
    'your_invoice' => 'Factura dumneavoastră',
    'remove_contact' => 'Șterge contact',
    'add_contact' => 'Adauga contact',
    'create_new_client' => 'Creaza client nou',
    'edit_client_details' => 'Modifica detalii client',
    'enable' => 'Activeaza',
    'learn_more' => 'Afla mai mult',
    'manage_rates' => 'Editeaza Rate',
    'note_to_client' => 'Mesaj Client',
    'invoice_terms' => 'Termeni facturare',
    'save_as_default_terms' => 'Salveaza ca predefinit',
    'download_pdf' => 'Descarca PDF',
    'pay_now' => 'Plateste acum',
    'save_invoice' => 'Salveaza factura',
    'clone_invoice' => 'Multiplică in Factură',
    'archive_invoice' => 'Arhiveaza factura',
    'delete_invoice' => 'Sterge factura',
    'email_invoice' => 'Trimite email',
    'enter_payment' => 'Introdu plata',
    'tax_rates' => 'Valori taxa',
    'rate' => 'Valoare',
    'settings' => 'Setari',
    'enable_invoice_tax' => 'Activează specificarea <b>taxei pe factură</b>',
    'enable_line_item_tax' => 'Activează specificarea <b>taxei pe fiecare element al facturii</b>',
    'dashboard' => 'Panou Control',
    'dashboard_totals_in_all_currencies_help' => 'Note: add a :link named ":name" to show the totals using a single base currency.',
    'clients' => 'Clienti',
    'invoices' => 'Facturi',
    'payments' => 'Plati',
    'credits' => 'Credite',
    'history' => 'Istoric',
    'search' => 'Cauta',
    'sign_up' => 'Inscrie-te',
    'guest' => 'Anonim',
    'company_details' => 'Detalii companie',
    'online_payments' => 'Plati online',
    'notifications' => 'Notificări',
    'import_export' => 'Import | Export',
    'done' => 'Gata',
    'save' => 'Salveaza',
    'create' => 'Creaza',
    'upload' => 'Incarca',
    'import' => 'Importa',
    'download' => 'Descarca',
    'cancel' => 'Renunta',
    'close' => 'Inchide',
    'provide_email' => 'Te rog sa dai o adresa email corecta',
    'powered_by' => 'Creat de',
    'no_items' => 'Nici un element',
    'recurring_invoices' => 'Facturi Recurente',
    'recurring_help' => '<p>In mod automatic trimite clientilor aceleasi facturi saptamanal, bi - lunar, lunar, trimestral sau anual.</p>
<p>Se foloseste: LUNA, :TRIMESTRU sau : AN pentru date dinamice. Calcule elementare functioneaza de asemenea, de exemplu : LUNA-1.</p>
<p>Exemple de facturi dinamice variabile: </p>
<ul>
<li>"Membru gym pentru luna : LUNA ">> "Membru gym pentru luna Iulie"</li>
<li>"AN+1 inscriere anuala ">>"2015 Inscriere Anuala"</li>
<li>"Plata pentru : TRIMESTRU+1">> "Plata pentru Q2"</li>
</ul>',
    'recurring_quotes' => 'Proforme Recurente',
    'in_total_revenue' => 'in total venituri',
    'billed_client' => 'client facturat',
    'billed_clients' => 'clienti facturati',
    'active_client' => 'client activ',
    'active_clients' => 'clienti activi',
    'invoices_past_due' => 'Facturi Cu Termen Depasit',
    'upcoming_invoices' => 'Facturi urmatoare',
    'average_invoice' => 'Medie facturi',
    'archive' => 'Arhiva',
    'delete' => 'Sterge',
    'archive_client' => 'Arhiveaza client',
    'delete_client' => 'Sterge client',
    'archive_payment' => 'Arhiveaza plata',
    'delete_payment' => 'Sterge plata',
    'archive_credit' => 'Arhiveaza credit',
    'delete_credit' => 'Sterge credit',
    'show_archived_deleted' => 'Arata arhivate/sterse',
    'filter' => 'Filtreaza',
    'new_client' => 'Client nou',
    'new_invoice' => 'Factura noua',
    'new_payment' => 'Introdu plata',
    'new_credit' => 'Adaugă Credit',
    'contact' => 'Contact',
    'date_created' => 'Data crearii',
    'last_login' => 'Ultima autentificare',
    'balance' => 'Balanta',
    'action' => 'Actiune',
    'status' => 'Stare',
    'invoice_total' => 'Total factura',
    'frequency' => 'Frecventa',
    'range' => 'Interval',
    'start_date' => 'Data inceput',
    'end_date' => 'Data sfirsit',
    'transaction_reference' => 'Referinta tranzactie',
    'method' => 'Metoda',
    'payment_amount' => 'Valoare plata',
    'payment_date' => 'Data platii',
    'credit_amount' => 'Valoare credit',
    'credit_balance' => 'Soldul Creditului',
    'credit_date' => 'Data Creditului',
    'empty_table' => 'Nu exista informatii',
    'select' => 'Selecteaza',
    'edit_client' => 'Modifica client',
    'edit_invoice' => 'Modifica factura',
    'create_invoice' => 'Creaza factura',
    'enter_credit' => 'Adaugă Credit',
    'last_logged_in' => 'Ultima Autentificare',
    'details' => 'Detalii',
    'standing' => 'Curent',
    'credit' => 'Credit',
    'activity' => 'Activitate',
    'date' => 'Data',
    'message' => 'Mesaj',
    'adjustment' => 'Ajustari',
    'are_you_sure' => 'Sigur?',
    'payment_type_id' => 'Tip plata',
    'amount' => 'Valoare',
    'work_email' => 'Email',
    'language_id' => 'Limba',
    'timezone_id' => 'Fus orar',
    'date_format_id' => 'Format data',
    'datetime_format_id' => 'Format Data/Ora',
    'users' => 'Utilizatori',
    'localization' => 'Localizare',
    'remove_logo' => 'Indeparteaza logo',
    'logo_help' => 'Fisiere suportate: JPEG, GIF si PNG',
    'payment_gateway' => 'Procesator Plata',
    'gateway_id' => 'Procesator',
    'email_notifications' => 'Notificari email',
    'email_sent' => 'Trimite-mi un email cind o factura este <b>trimisa</b>',
    'email_viewed' => 'Trimite-mi un email cind o factura este <b>vizualizata</b>',
    'email_paid' => 'Trimite-mi un email cind o factura este <b>platita</b>',
    'site_updates' => 'Actualizari site',
    'custom_messages' => 'Mesaje personalizate',
    'default_email_footer' => 'Setare ca implicit a <b>semnăturii în email</b>',
    'select_file' => 'Alege un fisier',
    'first_row_headers' => 'Folosește primul rând ca header',
    'column' => 'Coloana',
    'sample' => 'Exemplar',
    'import_to' => 'Importa In',
    'client_will_create' => 'clientul va fi creat',
    'clients_will_create' => 'clientii vor fi creati',
    'email_settings' => 'Setari email',
    'client_view_styling' => 'Modul în care este văzut de client',
    'pdf_email_attachment' => 'Atașează PDF',
    'custom_css' => 'Editeaza CSS',
    'import_clients' => 'Importa Date Clienti',
    'csv_file' => 'fisier CSV',
    'export_clients' => 'Exporta Date Client',
    'created_client' => 'S-a creat clientul cu succes',
    'created_clients' => 'Succes creare :count client(i)',
    'updated_settings' => 'Setari actualizate cu succes',
    'removed_logo' => 'Logo sters cu succes',
    'sent_message' => 'Mesaj trimis cu succes',
    'invoice_error' => 'Te rog alege un client si corecteaza erorile',
    'limit_clients' => 'Ne pare rau, aceasta va depasi numarul de :count clienti',
    'payment_error' => 'A fost o eroare in procesarea platii. Te rog sa incerci mai tarizu.',
    'registration_required' => 'Te rog inscrie-te ca sa trimiti o factura pe email.',
    'confirmation_required' => 'Confirmați adresa dvs. de e-mail, :link pentru a retrimite e-mailul de confirmare.',
    'updated_client' => 'Client actualizat cu succes.',
    'archived_client' => 'Client arhivat cu succes.',
    'archived_clients' => ':count clienti arhivat cu succes.',
    'deleted_client' => 'Client sters cu succes.',
    'deleted_clients' => ':count clienti stersi cu succes.',
    'updated_invoice' => 'Factura actualiazata cu succes.',
    'created_invoice' => 'Factura creata cu succes.',
    'cloned_invoice' => 'Factura clonata cu succes.',
    'emailed_invoice' => 'Factura trimisa pe email cu succes',
    'and_created_client' => 'si client creat',
    'archived_invoice' => 'Factura arhivata cu succes.',
    'archived_invoices' => ':count facturi arhivate cu succes.',
    'deleted_invoice' => 'Factura stearsa cu succes.',
    'deleted_invoices' => ':count facturi sterse cu succes',
    'created_payment' => 'Plata creata cu succes.',
    'created_payments' => ':count plata(i) create cu succes',
    'archived_payment' => 'Plata arhivata cu succes',
    'archived_payments' => ':count plati arhivate cu succes',
    'deleted_payment' => 'Plata stearsa cu succes.',
    'deleted_payments' => ':count plati sterse cu succes.',
    'applied_payment' => 'S-a aplicat plata cu succes',
    'created_credit' => 'Credit adăugat cu succes',
    'archived_credit' => 'Credit arhivat cu succes',
    'archived_credits' => ':count credite au fost arhivate cu succes',
    'deleted_credit' => 'Credit șters',
    'deleted_credits' => ':count șters',
    'imported_file' => 'Fișier importat cu succes',
    'updated_vendor' => 'Furnizor actualizat cu succes',
    'created_vendor' => 'Furnizor creat cu succes',
    'archived_vendor' => 'Furnizor arhivat cu succes',
    'archived_vendors' => ':count furnizori arhivați cu succes',
    'deleted_vendor' => 'Furnizor șters cu succes',
    'deleted_vendors' => ':count furnizori ștersi cu succes',
    'confirmation_subject' => 'Cont Invoice Ninja confirmat',
    'confirmation_header' => 'Confirmare cont',
    'confirmation_message' => 'Te rugăm accesează link-ul de mai jos pentru a confirma contul.',
    'invoice_subject' => 'Factură nouă :number de la :account',
    'invoice_message' => 'Pentru a vizualiza factura în valoare de :amount, apasă pe link-ul de mai jos.',
    'payment_subject' => 'Plată primită',
    'payment_message' => 'Mulțumim pentru plata în valoare de :amount',
    'email_salutation' => 'Draga :name,',
    'email_signature' => 'În legătură cu,',
    'email_from' => 'Echipa Invoice Ninja',
    'invoice_link_message' => 'Pentru a vizualiza factura apasă pe link-ul de mai jos:',
    'notification_invoice_paid_subject' => 'Factura :invoce a fost platita de :client',
    'notification_invoice_sent_subject' => 'Factura :invoice a fost trimisă la :client',
    'notification_invoice_viewed_subject' => 'Factura :invoice a fost vizualizată de :client',
    'notification_invoice_paid' => 'O plată în valoare de :amount a fost făcută de :client pentru factura :invoice',
    'notification_invoice_sent' => 'Clientului :client a i-a fost trimisă factura :invoice în valoare de :amount.',
    'notification_invoice_viewed' => 'Clientul :client a vizualizat factura :invoice în valoare de :amount.',
    'reset_password' => 'Poți să iți resetezi parola contului accesând următorul buton:',
    'secure_payment' => 'Plată Securizată',
    'card_number' => 'Numar card',
    'expiration_month' => 'Luna expirarii',
    'expiration_year' => 'Anul expirarii',
    'cvv' => 'CVV',
    'logout' => 'Deconectare',
    'sign_up_to_save' => 'Înregistrează-te pentru a salva',
    'agree_to_terms' => 'Sunt de acord cu :terms',
    'terms_of_service' => 'Termenii Serviciului',
    'email_taken' => 'Adresa de email este deja înregistrată',
    'working' => 'În lucru',
    'success' => 'Succes',
    'success_message' => 'Te-ai înregistrat cu succes! Accesează link-ul primit pe adresa de email folosită la înregistrare pentru a confirma contul. ',
    'erase_data' => 'Contul tău nu este înregistrat. Toate datele for fi șterse',
    'password' => 'Parola',
    'pro_plan_product' => 'Pachet PRO',
    'pro_plan_success' => 'Mulțumim că ai ales pachetul Invoice Ninja\'s Pro!1&nbsp;2
3Pașii următori34O factură a fost trimisă pe adresa de email
asociată contului tău. Pentru a debloca cele mai tari
opțiuni Pro, vă rugăm să urmăriți instrucțiunile de pe factură
pentru un an de nivel Pro de facturare.5
Nu găsești factura? Ai nevoie de asistență suplimentară? Suntem aici sa ajutăm
-- trimite-ne un email la contact@invoiceninja.com',
    'unsaved_changes' => 'Ai modificari nesalvate',
    'custom_fields' => 'Câmpuri personalizate',
    'company_fields' => 'Câmpuri Persoana Juridică',
    'client_fields' => 'Câmpuri Clienți',
    'field_label' => 'Etichetă cămp',
    'field_value' => 'Valoare câmp',
    'edit' => 'Modifica',
    'set_name' => 'Completează numele firme',
    'view_as_recipient' => 'Vezi ca destinatar',
    'product_library' => 'Librăria de produse',
    'product' => 'Produs',
    'products' => 'Produse',
    'fill_products' => 'Completează automat produsele',
    'fill_products_help' => 'Alegând un produs <b> descrierea și prețul</b> vor fi completate automat',
    'update_products' => 'Actualizare automată a produselor',
    'update_products_help' => 'Actualizând o factură se va actualiza si <b>librăria de produse</b>',
    'create_product' => 'Adauga produs',
    'edit_product' => 'Modifica produs',
    'archive_product' => 'Arhivă produse',
    'updated_product' => 'Produs actualizat cu succes',
    'created_product' => 'Produs creat cu succes',
    'archived_product' => 'Produs arhivat cu succes',
    'pro_plan_custom_fields' => ':link pentru a activa câmpurile personalizate dacă te abonezi la Pachetul PRO',
    'advanced_settings' => 'Opțiuni avansate',
    'pro_plan_advanced_settings' => ':link pentru a activa opțiunile avansate dacă te abonezi la Pachetul PRO',
    'invoice_design' => 'Design factură',
    'specify_colors' => 'Specifică culori',
    'specify_colors_label' => 'Alege culorile utilizate în factură',
    'chart_builder' => 'Creator grafice',
    'ninja_email_footer' => 'Creat de :site | Emite. Trimite. Încasează.',
    'go_pro' => 'Abonare la pachetul PRO',
    'quote' => 'Proforma',
    'quotes' => 'Proforme',
    'quote_number' => 'Numar Proforma',
    'quote_number_short' => 'Proforma #',
    'quote_date' => 'Data Proforma',
    'quote_total' => 'Total Proforma',
    'your_quote' => 'Proforma Ta',
    'total' => 'Total',
    'clone' => 'Multiplică',
    'new_quote' => 'Proforma Nou',
    'create_quote' => 'Creaza Proforma',
    'edit_quote' => 'Modifica Proforma',
    'archive_quote' => 'Arhveaza Proforma',
    'delete_quote' => 'Sterge Proforma',
    'save_quote' => 'Salveaza Proforma',
    'email_quote' => 'Trimite Proforma',
    'clone_quote' => 'Multiplică în Proformă',
    'convert_to_invoice' => 'Transformă în Factură',
    'view_invoice' => 'Vizualizare Factură',
    'view_client' => 'Vizualizare Client',
    'view_quote' => 'Vizualizare Ofertă',
    'updated_quote' => 'Proformă actualizată cu succes',
    'created_quote' => 'Proformă creată cu succes',
    'cloned_quote' => 'Proformă multiplicată cu succes',
    'emailed_quote' => 'Proformă trimisă cu succes',
    'archived_quote' => 'Proformă arhivată cu succes',
    'archived_quotes' => ':count proforme arhivate cu succes',
    'deleted_quote' => 'Proformă ștearsă',
    'deleted_quotes' => ':count proforme șterse cu succes',
    'converted_to_invoice' => 'Proformă transformată în factură cu succes',
    'quote_subject' => 'Proformă nouă :number de la :account',
    'quote_message' => 'Pentru a vizualiza proforma pentru :amount, accesează link-ul de mai jos.',
    'quote_link_message' => 'Pentru a vedea proforma clientului accesează link-ul de mai jos:',
    'notification_quote_sent_subject' => 'Proforma :invoice a fost trimisă la :client',
    'notification_quote_viewed_subject' => 'Proforma :invoice a fost vizualizată de :client',
    'notification_quote_sent' => 'Următorul client :client a primit Proforma :invoice în valoare de :amount.',
    'notification_quote_viewed' => 'Următorul client :client a vizualizat Proforma :invoice în valoare de :amount.',
    'session_expired' => 'Sesiunea a expirat.',
    'invoice_fields' => 'Câmpuri Factură',
    'invoice_options' => 'Opțiuni Factură',
    'hide_paid_to_date' => 'Ascunde câmpul "Plătit până la"',
    'hide_paid_to_date_help' => 'Afișează "Plătit pana la" decât când plata a fost efectuată.',
    'charge_taxes' => 'Taxe',
    'user_management' => 'Utilizatori',
    'add_user' => 'Adaugă utilizator',
    'send_invite' => 'Trimite Invitație',
    'sent_invite' => 'Invitație trimisă',
    'updated_user' => 'Utilizator actualizat',
    'invitation_message' => 'Ai fost invitat de :invitor.',
    'register_to_add_user' => 'Înregistrează-te pentru a adaugă un utilizator',
    'user_state' => 'Stat/Județ',
    'edit_user' => 'Modifică Utilizator',
    'delete_user' => 'Șterge utilizator',
    'active' => 'Activ',
    'pending' => 'În așteptare',
    'deleted_user' => 'Utilizator șters',
    'confirm_email_invoice' => 'Ești sigur că vrei să trimiți acestă factură?',
    'confirm_email_quote' => 'Ești sigur că vrei să trimiți acestă ofertă?',
    'confirm_recurring_email_invoice' => 'Ești sigur că vrei să trimiți acestă factură?',
    'confirm_recurring_email_invoice_not_sent' => 'Ești sigur că vrei să începi recurența?',
    'cancel_account' => 'Șterge cont',
    'cancel_account_message' => 'ATENȚIE: Toate datele vor fi șterse definitiv, nu se pot recupera.',
    'go_back' => 'Înapoi',
    'data_visualizations' => 'Vizualizare Date',
    'sample_data' => 'Sample data shown',
    'hide' => 'Ascunde',
    'new_version_available' => 'O nouă versiune de :releases_link este disponibilă. Versiunea ta este v:user_version, ultima versiune este v:latest_version',
    'invoice_settings' => 'Opțiuni Factură',
    'invoice_number_prefix' => 'Prefix Factură',
    'invoice_number_counter' => 'Plajă număr factură',
    'quote_number_prefix' => 'Prefix Proformă',
    'quote_number_counter' => 'Plajă număr proformă',
    'share_invoice_counter' => 'Share invoice counter',
    'invoice_issued_to' => 'Factură emisă câtre',
    'invalid_counter' => 'Pentru a evita orice conflict te rugăm să completezi un prefix la factuă sau la ofertă',
    'mark_sent' => 'Marchează ca trimis',
    'gateway_help_1' => ':link pentru înregistrare la Authorize.net.',
    'gateway_help_2' => ':link pentru înregistrare la Authorize.net.',
    'gateway_help_17' => ':link pentru obținere API PAYPAL',
    'gateway_help_27' => ':link to sign up for 2Checkout.com. To ensure payments are tracked set :complete_link as the redirect URL under Account > Site Management in the 2Checkout portal.',
    'gateway_help_60' => ':link to create a WePay account.',
    'more_designs' => 'Mai multe modele',
    'more_designs_title' => 'Alte modele de Facturi',
    'more_designs_cloud_header' => 'Abonează-te pentru mai multe modele de facturi',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Cumpără',
    'bought_designs' => 'Au fost adăugate alte modele de facturi',
    'sent' => 'Trimis',
    'vat_number' => 'C.I.F.',
    'timesheets' => 'Evidența timpului',
    'payment_title' => 'Completează adresa de facturare si datele Cardului de Credit',
    'payment_cvv' => '*Acesta este numărul de 3-4 cifre de pe spatele cardului bancar',
    'payment_footer1' => '*Adresa de facturare trebuie să se potrivească cu cea de pe Card',
    'payment_footer2' => '*Apasă doar o dată pe "PLĂTEȘTE ACUM" - tranzacția poate dura până la 1 minut pentru a fi procesată.',
    'id_number' => 'Nr. Reg. Com.',
    'white_label_link' => 'White label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'Successfully enabled white label license',
    'white_labeled' => 'White labeled',
    'restore' => 'Restaurează',
    'restore_invoice' => 'Restaureză Factura',
    'restore_quote' => 'Restaureză Proformă',
    'restore_client' => 'Restaurează Client',
    'restore_credit' => 'Restaurează Credit',
    'restore_payment' => 'Restaurează Plată',
    'restored_invoice' => 'Factură restaurată',
    'restored_quote' => 'Proformă restaurată',
    'restored_client' => 'Client restaurat',
    'restored_payment' => 'Plată restaurată',
    'restored_credit' => 'Credit restaurat',
    'reason_for_canceling' => 'Te rugăm să motivezi părăsirea acestui serviciu. Ne va ajuta să devenim mai buni.',
    'discount_percent' => 'Procent',
    'discount_amount' => 'Sumă',
    'invoice_history' => 'Istoric facturi',
    'quote_history' => 'Istoric Oferte',
    'current_version' => 'Versiunea Curentă',
    'select_version' => 'Alege versiune',
    'view_history' => 'Vizualizare Istoric',
    'edit_payment' => 'Modifică Plata',
    'updated_payment' => 'Plată actualizată',
    'deleted' => 'Șters',
    'restore_user' => 'Restaurează Utilizator',
    'restored_user' => 'Utilizator restaurat',
    'show_deleted_users' => 'Arată utilizatori șțerși',
    'email_templates' => 'Model Email',
    'invoice_email' => 'Email Factură',
    'payment_email' => 'Email Plată',
    'quote_email' => 'Email Ofertă',
    'reset_all' => 'Resetează tot',
    'approve' => 'Aprobă',
    'token_billing_type_id' => 'Token facturare',
    'token_billing_help' => 'Store payment details with WePay, Stripe, Braintree or GoCardless.',
    'token_billing_1' => 'Dezactivat.',
    'token_billing_2' => 'Opt-in - checkbox is shown but not selected',
    'token_billing_3' => 'Opt-out - checkbox is shown and selected',
    'token_billing_4' => 'Întotdeaunea',
    'token_billing_checkbox' => 'Salveză datele Cardurilor',
    'view_in_gateway' => 'Vizualizare în :gateway',
    'use_card_on_file' => 'Folosește card-ul salvat',
    'edit_payment_details' => 'Modifică detaliile plății',
    'token_billing' => 'Salvează datele cardului',
    'token_billing_secure' => 'Datele sunt păstrare în siguranță de :link',
    'support' => 'Asistență',
    'contact_information' => 'Date de contact',
    '256_encryption' => 'Encripție de 256-Biți',
    'amount_due' => 'Sumă de plată',
    'billing_address' => 'Adresă de facturare',
    'billing_method' => 'Metodă de facturare',
    'order_overview' => 'Rezumat comandă',
    'match_address' => '*Adresa trebuie să se potrivească cu cea asociată Card-ului',
    'click_once' => '*Apasă doar o dată pe "PLĂTEȘTE ACUM" - tranzacția poate dura până la 1 minut pentru a fi procesată.',
    'invoice_footer' => 'Subsol Factură',
    'save_as_default_footer' => 'Salvează ca subsol implicit',
    'token_management' => 'Management Token-uri',
    'tokens' => 'Token-uri',
    'add_token' => 'Adaugă Token',
    'show_deleted_tokens' => 'Arată Token-urile șterse',
    'deleted_token' => 'Token șters',
    'created_token' => 'Token creat',
    'updated_token' => 'Actualizează token',
    'edit_token' => 'Modifica token',
    'delete_token' => 'Șterge Token',
    'token' => 'Token',
    'add_gateway' => 'Adaugă Gateway',
    'delete_gateway' => 'Șterge Gateway',
    'edit_gateway' => 'Modifică Gateway',
    'updated_gateway' => 'Gateway actualizat',
    'created_gateway' => 'Gateway creat',
    'deleted_gateway' => 'Gateway șters',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Card de Credit',
    'change_password' => 'Schimbă parola',
    'current_password' => 'Parola actuală',
    'new_password' => 'Noua parolă',
    'confirm_password' => 'Confirmă noua parolă',
    'password_error_incorrect' => 'Parola actuală este incorectă.',
    'password_error_invalid' => 'Noua parolă este invalidă.',
    'updated_password' => 'Parolă actualizată',
    'api_tokens' => 'Token API',
    'users_and_tokens' => 'Utilizatori & Token-uri',
    'account_login' => 'Autentificare',
    'recover_password' => 'Recuperează parola',
    'forgot_password' => 'Ai uitat parola?',
    'email_address' => 'Adresă email',
    'lets_go' => 'Mai departe',
    'password_recovery' => 'Recuperare Parolă',
    'send_email' => 'Trimite Email',
    'set_password' => 'Stabilește Parola',
    'converted' => 'Transformă',
    'email_approved' => 'Trimite-mi un email când Proforma este <b>aprobată</b>',
    'notification_quote_approved_subject' => 'Proforma :invoice a fost aprobată de :client',
    'notification_quote_approved' => ':client a aprobat Proforma :invoice în valoare de :amount.',
    'resend_confirmation' => 'Retrimite email confirmare',
    'confirmation_resent' => 'Email-ul de confirmare a fost trimis',
    'gateway_help_42' => ':link pentru înscriere la BitPay. <br/>
Atentie: Folosește Legacy API Key, nu Token API',
    'payment_type_credit_card' => 'Card de Credit',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Baza de cunoștințe',
    'partial' => 'Parțial/Depunere',
    'partial_remaining' => ':partial din :balance',
    'more_fields' => 'Mai multe câmpuri',
    'less_fields' => 'Mai puține câmpuri',
    'client_name' => 'Nume Client',
    'pdf_settings' => 'Opțiuni PDF',
    'product_settings' => 'Opțiuni Produs',
    'auto_wrap' => 'Linie nouă automată',
    'duplicate_post' => 'Atenție: pagina a fost transmisă de două ori. A doua transmitere a fost ignorată.',
    'view_documentation' => 'Vezi documentație',
    'app_title' => 'Facturare online gratuită și open source',
    'app_description' => 'Invoice Ninja este un program gratuit, open-source soluție pentru facturare. Cu Invoice Ninja, puteți construi  și trimite cu ușurință  facturi de pe orice dispozitiv care are acces la internet. clienții pot imprima facturile, descarca ca fișiere PDF, și chiar plătii online din cadrul sistemului.',
    'rows' => 'rânduri',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdomeniu',
    'provide_name_or_email' => 'Completează un nume sau o adresă de email',
    'charts_and_reports' => 'Rapoarte și grafice',
    'chart' => 'Grafic',
    'report' => 'Raport',
    'group_by' => 'Grupează după',
    'paid' => 'Plătit',
    'enable_report' => 'Raport',
    'enable_chart' => 'Grafic',
    'totals' => 'Total',
    'run' => 'Rulează',
    'export' => 'Exportă',
    'documentation' => 'Documentație',
    'zapier' => 'Zapier',
    'recurring' => 'Recurent',
    'last_invoice_sent' => 'Ultima factură trimisă la :date',
    'processed_updates' => 'Actualizare completă',
    'tasks' => 'Task-uri',
    'new_task' => 'Task nou',
    'start_time' => 'Timp pornire',
    'created_task' => 'Task creat',
    'updated_task' => 'Task actualizat',
    'edit_task' => 'Modifică Task',
    'clone_task' => 'Clone Task',
    'archive_task' => 'Athivează Task',
    'restore_task' => 'Restaurează Task',
    'delete_task' => 'Șterge Task',
    'stop_task' => 'Oprește Task',
    'time' => 'Timp',
    'start' => 'Start',
    'stop' => 'Stop',
    'now' => 'Acum',
    'timer' => 'Cronometru',
    'manual' => 'Manual',
    'date_and_time' => 'Data și Timpul',
    'second' => 'Secundă',
    'seconds' => 'Secunde',
    'minute' => 'Minut',
    'minutes' => 'Minute',
    'hour' => 'Oră',
    'hours' => 'Ore',
    'task_details' => 'Detalii Task',
    'duration' => 'Durată',
    'time_log' => 'Log Timp',
    'end_time' => 'Timp încheiere',
    'end' => 'Sfârșit',
    'invoiced' => 'Facturat',
    'logged' => 'Înregistrat',
    'running' => 'În derulare',
    'task_error_multiple_clients' => 'Task-ul nu poate aparține mai multor clienți',
    'task_error_running' => 'Oprește Task-ul înainte',
    'task_error_invoiced' => 'Task-urile au fost deja facturate',
    'restored_task' => 'Task restaurat',
    'archived_task' => 'Task arhivat',
    'archived_tasks' => 'Arhivat :count task-uri',
    'deleted_task' => 'Task șters',
    'deleted_tasks' => 'Șters :count task-uri',
    'create_task' => 'Crează Task',
    'stopped_task' => 'Task oprit',
    'invoice_task' => 'Făcturează task',
    'invoice_labels' => 'Etichete Facturare',
    'prefix' => 'Prefix',
    'counter' => 'Contor',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link pentru înregistrare la Dwolla',
    'partial_value' => 'Trebuie să fie mai mare ca zero și mai mic ca totalul',
    'more_actions' => 'Mai multe acțiuni',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Îmbunătățește acum!',
    'pro_plan_feature1' => 'Crează Clienți Nelimitați',
    'pro_plan_feature2' => '10 modele de Facturi',
    'pro_plan_feature3' => 'URL customizabil - "FirmaTa.InjoiceNinja.com"',
    'pro_plan_feature4' => 'Înlătură "Creat de Invoice Ninja"',
    'pro_plan_feature5' => 'Acces pentru mai mulți utilizatori și Monitorizarea Activității',
    'pro_plan_feature6' => 'Crează Oferte și Proforme',
    'pro_plan_feature7' => 'Personalizează câmpurile și numerotarea facturilor',
    'pro_plan_feature8' => 'Psobilitatea de a trimite facturile PDF pe email',
    'resume' => 'Continuă',
    'break_duration' => 'Întrerupe',
    'edit_details' => 'Modifică Detalii',
    'work' => 'Activitate',
    'timezone_unset' => 'Alege :link fusul orar',
    'click_here' => 'apasă aici',
    'email_receipt' => 'Trimite pe email dovada plății',
    'created_payment_emailed_client' => 'Plată creată și trimisă clientului',
    'add_company' => 'Adaugă Firmă',
    'untitled' => 'Fără titlu',
    'new_company' => 'Firmă nouă',
    'associated_accounts' => 'Conturi conectate',
    'unlinked_account' => 'Conturi deconectate',
    'login' => 'Autentificare',
    'or' => 'sau',
    'email_error' => 'A apărut o problemă la trimiterea email-ului',
    'confirm_recurring_timing' => 'Notă: emailurile sunt trimise la începutul orei.',
    'confirm_recurring_timing_not_sent' => 'Notă: facturile sunt create la începutul orei.',
    'payment_terms_help' => 'Sets the default <b>invoice due date</b>',
    'unlink_account' => 'Deconectează conturile',
    'unlink' => 'Deconectează',
    'show_address' => 'Arată Adresa',
    'show_address_help' => 'Roagă clientul să precizeze adresa de facturare',
    'update_address' => 'Actualizează Adresa',
    'update_address_help' => 'Actualizează adresa clientului cu detaliile trimise',
    'times' => 'Times',
    'set_now' => 'Setează acum',
    'dark_mode' => 'Mod întunecat',
    'dark_mode_help' => 'Use a dark background for the sidebars',
    'add_to_invoice' => 'Adaugă la factura :invoice',
    'create_new_invoice' => 'Creaza factura noua',
    'task_errors' => 'Te rog corectează suprapunerea timpilor',
    'from' => 'De la',
    'to' => 'Către',
    'font_size' => 'Dimensiune Font',
    'primary_color' => 'Culoare Principală',
    'secondary_color' => 'Culoare Secundară',
    'customize_design' => 'Personalizează Design',
    'content' => 'Conținut',
    'styles' => 'Stil',
    'defaults' => 'Implicit',
    'margins' => 'Margini',
    'header' => 'Antet',
    'footer' => 'Subsol',
    'custom' => 'Personalizat',
    'invoice_to' => 'Facturat catre',
    'invoice_no' => 'Factura Nr.',
    'quote_no' => 'Proforma Nr.',
    'recent_payments' => 'Plati recente',
    'outstanding' => 'Restante',
    'manage_companies' => 'Administreaza Firmele',
    'total_revenue' => 'Venituri Totale',
    'current_user' => 'Utilizator Curent',
    'new_recurring_invoice' => 'Adauga Factura Recurenta',
    'recurring_invoice' => 'Factura Recurenta',
    'new_recurring_quote' => 'Proformă Recurentă Nouă',
    'recurring_quote' => 'Proformă recurentă',
    'recurring_too_soon' => 'Este prea devreme pentru a crea următoarea factură recurentă, fiind programată pentru :date',
    'created_by_invoice' => 'Creat de :invoice',
    'primary_user' => 'Utilizator Principal',
    'help' => 'Ajutor',
    'customize_help' => '<p>We use :pdfmake_link to define the invoice designs declaratively. The pdfmake :playground_link provides a great way to see the library in action.</p>
                        <p>If you need help figuring something out post a question to our :forum_link with the design you\'re using.</p>',
    'playground' => 'playground',
    'support_forum' => 'forum suport',
    'invoice_due_date' => 'Data Scadenta',
    'quote_due_date' => 'Valabil până la',
    'valid_until' => 'Valabil până la',
    'reset_terms' => 'Resetează termenii',
    'reset_footer' => 'Resetează subsolul',
    'invoice_sent' => ':count factură trimisă',
    'invoices_sent' => ':count facturi trimise',
    'status_draft' => 'Ciorna',
    'status_sent' => 'Trimisa',
    'status_viewed' => 'Vizualizata',
    'status_partial' => 'Partial',
    'status_paid' => 'Platita',
    'status_unpaid' => 'Neplatita',
    'status_all' => 'Toate',
    'show_line_item_tax' => 'Display <b>line item taxes inline</b>',
    'iframe_url' => 'Website',
    'iframe_url_help1' => 'Copiază următorul cod pe o pagină din site-ul tău.',
    'iframe_url_help2' => 'Poți testa opțiunea dând click pe \'View as recipient\' pe o factură.',
    'auto_bill' => 'Auto Facturare',
    'military_time' => 'Format 24 Ore',
    'last_sent' => 'Ultimul trimis',
    'reminder_emails' => 'Emailuri Notificări',
    'quote_reminder_emails' => 'Notificări Emailuri Proforme',
    'templates_and_reminders' => 'Șabloane & Notificări',
    'subject' => 'Subiect',
    'body' => 'Mesaj',
    'first_reminder' => 'Prima Notificare',
    'second_reminder' => 'A Doua Notificare',
    'third_reminder' => 'A Treia Notificare',
    'num_days_reminder' => 'Zile dupa scadenta',
    'reminder_subject' => 'Notificare: Factura :invoice de la :account',
    'reset' => 'Resetează',
    'invoice_not_found' => 'Factura respectivă nu este disponibilă',
    'referral_program' => 'Program Promovare',
    'referral_code' => 'URL Promovare',
    'last_sent_on' => 'Ultimul trimis :date',
    'page_expire' => 'Această pagină va expira în curând, :click_here pentru a continua să lucrezi',
    'upcoming_quotes' => 'Proforme următoare',
    'expired_quotes' => 'Proforme expirate',
    'sign_up_using' => 'Înscrie-te folosind',
    'invalid_credentials' => 'Aceste credențiale nu coincid cu datele noastre',
    'show_all_options' => 'Arata toate optiunile',
    'user_details' => 'Detalii utilizator',
    'oneclick_login' => 'Cont Conectat',
    'disable' => 'Dezactiveaza',
    'invoice_quote_number' => 'Numere Facturi și Proforme',
    'invoice_charges' => 'Taxe Suplimentare',
    'notification_invoice_bounced' => 'Nu am putut trimite Factura :invoice către :contact.',
    'notification_invoice_bounced_subject' => 'Nu se poate trimite Factura :invoice',
    'notification_quote_bounced' => 'Nu am putut trimite Proforma :invoice către :contact.',
    'notification_quote_bounced_subject' => 'Nu se poate trimite Proforma :invoice',
    'custom_invoice_link' => 'Link Factura Personalizat',
    'total_invoiced' => 'Total Facturat',
    'open_balance' => 'Open Balance',
    'verify_email' => 'Please visit the link in the account confirmation email to verify your email address.',
    'basic_settings' => 'Opțiuni de bază',
    'pro' => 'Pro',
    'gateways' => 'Procesatori de Plată',
    'next_send_on' => 'Send Next: :date',
    'no_longer_running' => 'This invoice is not scheduled to run',
    'general_settings' => 'Optiuni Generale',
    'customize' => 'Personalizeaza',
    'oneclick_login_help' => 'Connect an account to login without a password',
    'referral_code_help' => 'Câștigă bani promovând aplicația noastră online',
    'enable_with_stripe' => 'Activează | Necesită Stripe',
    'tax_settings' => 'Setari Taxe',
    'create_tax_rate' => 'Adaugă Valoare Taxă',
    'updated_tax_rate' => 'Valoare taxă actualizată cu succes',
    'created_tax_rate' => 'Valoare taxă creată cu succes',
    'edit_tax_rate' => 'Editează valoare taxă',
    'archive_tax_rate' => 'Arhivează Valoare Taxă',
    'archived_tax_rate' => 'Valoare taxă arhivată cu succes',
    'default_tax_rate_id' => 'Valoare Taxă Implicită',
    'tax_rate' => 'Valoare Taxă',
    'recurring_hour' => 'Oră Recurentă',
    'pattern' => 'Schemă',
    'pattern_help_title' => 'Ajutor Schemă',
    'pattern_help_1' => 'Creează numere personalizate folosind o schemă',
    'pattern_help_2' => 'Variabile disponibile:',
    'pattern_help_3' => 'De exemplu, :example va fi transformat în :value',
    'see_options' => 'Vezi optiunile',
    'invoice_counter' => 'Contor Factura',
    'quote_counter' => 'Contor Proforma',
    'type' => 'Tip',
    'activity_1' => ':user a creat clientul :client',
    'activity_2' => ':user a arhivat clientul :client',
    'activity_3' => ':user a șters clientul :client',
    'activity_4' => ':user a creat factura :invoice',
    'activity_5' => ':user a actualizat factura :invoice',
    'activity_6' => ':user a trimis pe email factura :invoice pentru :client la :contact',
    'activity_7' => ':contact a vizualizat factura :invoice pentru :client',
    'activity_8' => ':user a arhivat factura :invoice',
    'activity_9' => ':user a șters factura :invoice',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user a actualizat plata :payment',
    'activity_12' => ':user a arhivat plata :payment',
    'activity_13' => ':user a șters plata :payment',
    'activity_14' => ':user a încărcat :credit credite',
    'activity_15' => ':user a actualizat :credit credite',
    'activity_16' => ':user a arhivat :credit credite',
    'activity_17' => ':user a șters :credit credite',
    'activity_18' => ':user a creat proforma :quote',
    'activity_19' => ':user a actualizat proforma :quote',
    'activity_20' => ':user a trimis pe email proforma :quote pentru :client la :contact',
    'activity_21' => ':contact a vizualizat proforma :quote',
    'activity_22' => ':user a arhivat proforma :quote',
    'activity_23' => ':user a șters proforma :quote',
    'activity_24' => ':user a restaurat proforma :quote',
    'activity_25' => ':user a restaurat factura :invoice',
    'activity_26' => ':user a restaurat clientul :client',
    'activity_27' => ':user a restaurat plata :payment',
    'activity_28' => ':user a restaurat :credit credite',
    'activity_29' => ':contact a aprobat proforma :quote pentru :client',
    'activity_30' => ':user a creat furnizorul :vendor',
    'activity_31' => ':user a arhivat furnizorul :vendor',
    'activity_32' => ':user a șters furnizorul :vendor',
    'activity_33' => ':user a restaurat furnizorul :vendor',
    'activity_34' => ':user a creat cheltuiala :expense',
    'activity_35' => ':user a arhivat cheltuiala :expense',
    'activity_36' => ':user a șters cheltuiala :expense',
    'activity_37' => ':user a restaurat cheltuiala :expense',
    'activity_42' => ':user created task :task',
    'activity_43' => ':user updated task :task',
    'activity_44' => ':user archived task :task',
    'activity_45' => ':user deleted task :task',
    'activity_46' => ':user restored task :task',
    'activity_47' => ':user updated expense :expense',
    'activity_48' => ':user updated ticket :ticket',
    'activity_49' => ':user closed ticket :ticket',
    'activity_50' => ':user merged ticket :ticket',
    'activity_51' => ':user split ticket :ticket',
    'activity_52' => ':contact opened ticket :ticket',
    'activity_53' => ':contact reopened ticket :ticket',
    'activity_54' => ':user reopened ticket :ticket',
    'activity_55' => ':contact replied ticket :ticket',
    'activity_56' => ':user viewed ticket :ticket',

    'payment' => 'Plata',
    'system' => 'Sistem',
    'signature' => 'Semnatura Email',
    'default_messages' => 'Mesaje Implicite',
    'quote_terms' => 'Termeni Proformă',
    'default_quote_terms' => 'Termeni Proforma Impliciți',
    'default_invoice_terms' => 'Termeni Factură Impliciți',
    'default_invoice_footer' => 'Subsol Factură Implicit',
    'quote_footer' => 'Subsol Proformă',
    'free' => 'Gratis',
    'quote_is_approved' => 'Aprobat cu succes',
    'apply_credit' => 'Apply Credit',
    'system_settings' => 'Setari Sistem',
    'archive_token' => 'Archive Token',
    'archived_token' => 'Successfully archived token',
    'archive_user' => 'Arhivează Utilizator',
    'archived_user' => 'Arhivare utilizator cu succes',
    'archive_account_gateway' => 'Șterge Procesator',
    'archived_account_gateway' => 'Procesator arhivat cu succes',
    'archive_recurring_invoice' => 'Arhivează Factură Recurentă',
    'archived_recurring_invoice' => 'Factură recurentă arhivată cu succes',
    'delete_recurring_invoice' => 'Șterge Factură Recurentă',
    'deleted_recurring_invoice' => 'Factură recurentă ștearsă cu succes',
    'restore_recurring_invoice' => 'Restaurează Factură Recurentă',
    'restored_recurring_invoice' => 'Factură recurentă restaurată cu succes',
    'archive_recurring_quote' => 'Arhivează Proformă Recurentă',
    'archived_recurring_quote' => 'Proformă recurentă arhivată cu succes',
    'delete_recurring_quote' => 'Șterge Proformă Recurentă',
    'deleted_recurring_quote' => 'Proformă recurentă ștearsă cu succes',
    'restore_recurring_quote' => 'Restaurează Proformă Recurentă',
    'restored_recurring_quote' => 'Proformă recurentă restaurată cu succes',
    'archived' => 'Arhivat',
    'untitled_account' => 'Firmă fără nume',
    'before' => 'Înainte',
    'after' => 'După',
    'reset_terms_help' => 'Resetează la termenii impliciți',
    'reset_footer_help' => 'Resetează la subsolul implicit',
    'export_data' => 'Exportă Date',
    'user' => 'Utilizator',
    'country' => 'Tara',
    'include' => 'Include',
    'logo_too_large' => 'Logo-ul tău are dimensiunea de :size, pentru o mai bună perfomanță a PDF-ului vă recomandăm să urcați o imagine cu o dimensiune mai mică de 200KB',
    'import_freshbooks' => 'Importă din FreshBooks',
    'import_data' => 'Importă Date',
    'source' => 'Sursă',
    'csv' => 'CSV',
    'client_file' => 'Fișier Client',
    'invoice_file' => 'Fișier Factură',
    'task_file' => 'Fișier Task',
    'no_mapper' => 'No valid mapping for file',
    'invalid_csv_header' => 'Invalid CSV Header',
    'client_portal' => 'Portal Client',
    'admin' => 'Admin',
    'disabled' => 'Dezactivat',
    'show_archived_users' => 'Show archived users',
    'notes' => 'Notițe',
    'invoice_will_create' => 'Factura va fi creată',
    'invoices_will_create' => 'Facturile vor fi create',
    'failed_to_import' => 'The following records failed to import, they either already exist or are missing required fields.',
    'publishable_key' => 'Publishable Key',
    'secret_key' => 'Cheia Secreta',
    'missing_publishable_key' => 'Set your Stripe publishable key for an improved checkout process',
    'email_design' => 'Design Email',
    'due_by' => 'Due by :date',
    'enable_email_markup' => 'Enable Markup',
    'enable_email_markup_help' => 'Make it easier for your clients to pay you by adding schema.org markup to your emails.',
    'template_help_title' => 'Templates Help',
    'template_help_1' => 'Available variables:',
    'email_design_id' => 'Email Style',
    'email_design_help' => 'Make your emails look more professional with HTML layouts.',
    'plain' => 'Plain',
    'light' => 'Deschisa',
    'dark' => 'Intunecata',
    'industry_help' => 'Used to provide comparisons against the averages of companies of similar size and industry.',
    'subdomain_help' => 'Set the subdomain or display the invoice on your own website.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the invoice number.',
    'quote_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the quote number.',
    'custom_client_fields_helps' => 'Add a field when creating a client and optionally display the label and value on the PDF.',
    'custom_account_fields_helps' => 'Add a label and value to the company details section of the PDF.',
    'custom_invoice_fields_helps' => 'Add a field when creating an invoice and optionally display the label and value on the PDF.',
    'custom_invoice_charges_helps' => 'Add a field when creating an invoice and include the charge in the invoice subtotals.',
    'token_expired' => 'Validation token was expired. Please try again.',
    'invoice_link' => 'Link Factură',
    'button_confirmation_message' => 'Click pentru a confirma adresa de email',
    'confirm' => 'Confirmă',
    'email_preferences' => 'Preferințe Email',
    'created_invoices' => 'Successfully created :count invoice(s)',
    'next_invoice_number' => 'Următorul număr de factură este :number.',
    'next_quote_number' => 'Următorul număr de proformă este :number.',
    'days_before' => 'days before the',
    'days_after' => 'days after the',
    'field_due_date' => 'data scadență',
    'field_invoice_date' => 'data factură',
    'schedule' => 'Schedule',
    'email_designs' => 'Email Designs',
    'assigned_when_sent' => 'Assigned when sent',
    'white_label_purchase_link' => 'Purchase a white label license',
    'expense' => 'Cheltuială',
    'expenses' => 'Cheltuieli',
    'new_expense' => 'Introdu Cheltuială',
    'enter_expense' => 'Introdu Cheltuială',
    'vendors' => 'Furnizori',
    'new_vendor' => 'Furnizor Nou',
    'payment_terms_net' => 'Net',
    'vendor' => 'Furnizor',
    'edit_vendor' => 'Editează Furnizor',
    'archive_vendor' => 'Arhivează Furnizor',
    'delete_vendor' => 'Șterge Furnizor',
    'view_vendor' => 'Vezi Furnizor',
    'deleted_expense' => 'Cheltuială ștearsă cu succes',
    'archived_expense' => 'Cheltuială arhivată cu succes',
    'deleted_expenses' => 'Cheltuieli șterse cu succes',
    'archived_expenses' => 'Cheltuieli arhivate cu succes',
    'expense_amount' => 'Valoare Cheltuieli',
    'expense_balance' => 'Expense Balance',
    'expense_date' => 'Expense Date',
    'expense_should_be_invoiced' => 'Should this expense be invoiced?',
    'public_notes' => 'Public Notes',
    'invoice_amount' => 'Valoare Factură',
    'exchange_rate' => 'Curs Valutar',
    'yes' => 'Da',
    'no' => 'Nu',
    'should_be_invoiced' => 'Should be invoiced',
    'view_expense' => 'View expense # :expense',
    'edit_expense' => 'Edit Expense',
    'archive_expense' => 'Archive Expense',
    'delete_expense' => 'Delete Expense',
    'view_expense_num' => 'Expense # :expense',
    'updated_expense' => 'Successfully updated expense',
    'created_expense' => 'Successfully created expense',
    'enter_expense' => 'Introdu Cheltuială',
    'view' => 'Vezi',
    'restore_expense' => 'Restore Expense',
    'invoice_expense' => 'Invoice Expense',
    'expense_error_multiple_clients' => 'The expenses can\'t belong to different clients',
    'expense_error_invoiced' => 'Expense has already been invoiced',
    'convert_currency' => 'Transformă moneda',
    'num_days' => 'Number of Days',
    'create_payment_term' => 'Create Payment Term',
    'edit_payment_terms' => 'Edit Payment Term',
    'edit_payment_term' => 'Edit Payment Term',
    'archive_payment_term' => 'Archive Payment Term',
    'recurring_due_dates' => 'Recurring Invoice Due Dates',
    'recurring_due_date_help' => '<p>Automatically sets a due date for the invoice.</p>
        <p>Invoices on a monthly or yearly cycle set to be due on or before the day they are created will be due the next month. Invoices set to be due on the 29th or 30th in months that don\'t have that day will be due the last day of the month.</p>
        <p>Invoices on a weekly cycle set to be due on the day of the week they are created will be due the next week.</p>
        <p>For example:</p>
        <ul>
          <li>Today is the 15th, due date is 1st of the month. The due date should likely be the 1st of the next month.</li>
          <li>Today is the 15th, due date is the last day of the month. The due date will be the last day of the this month.
</li>
          <li>Today is the 15th, due date is the 15th day of the month. The due date will be the 15th day of <strong>next</strong> month.
</li>
          <li>Today is the Friday, due date is the 1st Friday after. The due date will be next Friday, not today.
</li>
        </ul>',
    'due' => 'Scadență',
    'next_due_on' => 'Due Next: :date',
    'use_client_terms' => 'Use client terms',
    'day_of_month' => ':ordinal day of month',
    'last_day_of_month' => 'Ultima zi din lună',
    'day_of_week_after' => ':ordinal :day after',
    'sunday' => 'Duminică',
    'monday' => 'Luni',
    'tuesday' => 'Marți',
    'wednesday' => 'Miercuri',
    'thursday' => 'Joi',
    'friday' => 'Vineri',
    'saturday' => 'Sâmbătă',
    'header_font_id' => 'Header Font',
    'body_font_id' => 'Body Font',
    'color_font_help' => 'Note: the primary color and fonts are also used in the client portal and custom email designs.',
    'live_preview' => 'Live Preview',
    'invalid_mail_config' => 'Unable to send email, please check that the mail settings are correct.',
    'invoice_message_button' => 'To view your invoice for :amount, click the button below.',
    'quote_message_button' => 'To view your quote for :amount, click the button below.',
    'payment_message_button' => 'Thank you for your payment of :amount.',
    'payment_type_direct_debit' => 'Direct Debit',
    'bank_accounts' => 'Credit Cards & Banks',
    'add_bank_account' => 'Add Bank Account',
    'setup_account' => 'Setup Account',
    'import_expenses' => 'Import Expenses',
    'bank_id' => 'Banca',
    'integration_type' => 'Integration Type',
    'updated_bank_account' => 'Successfully updated bank account',
    'edit_bank_account' => 'Edit Bank Account',
    'archive_bank_account' => 'Archive Bank Account',
    'archived_bank_account' => 'Successfully archived bank account',
    'created_bank_account' => 'Successfully created bank account',
    'validate_bank_account' => 'Validate Bank Account',
    'bank_password_help' => 'Note: your password is transmitted securely and never stored on our servers.',
    'bank_password_warning' => 'Warning: your password may be transmitted in plain text, consider enabling HTTPS.',
    'username' => 'Username',
    'account_number' => 'Account Number',
    'account_name' => 'Account Name',
    'bank_account_error' => 'Failed to retrieve account details, please check your credentials.',
    'status_approved' => 'Approved',
    'quote_settings' => 'Setări Proforme',
    'auto_convert_quote' => 'Auto Convert',
    'auto_convert_quote_help' => 'Automatically convert a quote to an invoice when approved by a client.',
    'validate' => 'Validează',
    'info' => 'Info',
    'imported_expenses' => 'Successfully created :count_vendors vendor(s) and :count_expenses expense(s)',
    'iframe_url_help3' => 'Note: if you plan on accepting credit cards details we strongly recommend enabling HTTPS on your site.',
    'expense_error_multiple_currencies' => 'The expenses can\'t have different currencies.',
    'expense_error_mismatch_currencies' => 'The client\'s currency does not match the expense currency.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Antet/Subsol',
    'first_page' => 'Prima pagină',
    'all_pages' => 'Toate paginile',
    'last_page' => 'Ultima pagină',
    'all_pages_header' => 'Show Header on',
    'all_pages_footer' => 'Show Footer on',
    'invoice_currency' => 'Moneda Facturii',
    'enable_https' => 'We strongly recommend using HTTPS to accept credit card details online.',
    'quote_issued_to' => 'Proformă emisă către',
    'show_currency_code' => 'Cod Monedă',
    'free_year_message' => 'Your account has been upgraded to the pro plan for one year at no cost.',
    'trial_message' => 'Your account will receive a free two week trial of our pro plan.',
    'trial_footer' => 'Your free pro plan trial lasts :count more days, :link to upgrade now.',
    'trial_footer_last_day' => 'This is the last day of your free pro plan trial, :link to upgrade now.',
    'trial_call_to_action' => 'Start Free Trial',
    'trial_success' => 'Successfully enabled two week free pro plan trial',
    'overdue' => 'Overdue',


    'white_label_text' => 'Purchase a ONE YEAR white label license for $:price to remove the Invoice Ninja branding from the invoice and client portal.',
    'user_email_footer' => 'To adjust your email notification settings please visit :link',
    'reset_password_footer' => 'If you did not request this password reset please email our support: :email',
    'limit_users' => 'Sorry, this will exceed the limit of :limit users',
    'more_designs_self_host_header' => 'Get 6 more invoice designs for just $:price',
    'old_browser' => 'Please use a :link',
    'newer_browser' => 'newer browser',
    'white_label_custom_css' => ':link for $:price to enable custom styling and help support our project.',
    'bank_accounts_help' => 'Connect a bank account to automatically import expenses and create vendors. Supports American Express and :link.',
    'us_banks' => '400+ US banks',

    'pro_plan_remove_logo' => ':link to remove the Invoice Ninja logo by joining the Pro Plan',
    'pro_plan_remove_logo_link' => 'Click here',
    'invitation_status_sent' => 'Sent',
    'invitation_status_opened' => 'Opened',
    'invitation_status_viewed' => 'Viewed',
    'email_error_inactive_client' => 'Emails can not be sent to inactive clients',
    'email_error_inactive_contact' => 'Emails can not be sent to inactive contacts',
    'email_error_inactive_invoice' => 'Emails can not be sent to inactive invoices',
    'email_error_inactive_proposal' => 'Emails can not be sent to inactive proposals',
    'email_error_user_unregistered' => 'Please register your account to send emails',
    'email_error_user_unconfirmed' => 'Please confirm your account to send emails',
    'email_error_invalid_contact_email' => 'Invalid contact email',

    'navigation' => 'Navigation',
    'list_invoices' => 'List Invoices',
    'list_clients' => 'List Clients',
    'list_quotes' => 'List Quotes',
    'list_tasks' => 'List Tasks',
    'list_expenses' => 'List Expenses',
    'list_recurring_invoices' => 'List Recurring Invoices',
    'list_payments' => 'List Payments',
    'list_credits' => 'List Credits',
    'tax_name' => 'Tax Name',
    'report_settings' => 'Report Settings',
    'search_hotkey' => 'shortcut is /',

    'new_user' => 'New User',
    'new_product' => 'New Product',
    'new_tax_rate' => 'New Tax Rate',
    'invoiced_amount' => 'Invoiced Amount',
    'invoice_item_fields' => 'Invoice Item Fields',
    'custom_invoice_item_fields_help' => 'Add a field when creating an invoice item and display the label and value on the PDF.',
    'recurring_invoice_number' => 'Recurring Number',
    'recurring_invoice_number_prefix_help' => 'Specify a prefix to be added to the invoice number for recurring invoices.',

    // Client Passwords
    'enable_portal_password' => 'Password Protect Invoices',
    'enable_portal_password_help' => 'Allows you to set a password for each contact. If a password is set, the contact will be required to enter a password before viewing invoices.',
    'send_portal_password' => 'Generate Automatically',
    'send_portal_password_help' => 'If no password is set, one will be generated and sent with the first invoice.',

    'expired' => 'Expired',
    'invalid_card_number' => 'The credit card number is not valid.',
    'invalid_expiry' => 'The expiration date is not valid.',
    'invalid_cvv' => 'The CVV is not valid.',
    'cost' => 'Cost',
    'create_invoice_for_sample' => 'Note: create your first invoice to see a preview here.',

    // User Permissions
    'owner' => 'Owner',
    'administrator' => 'Administrator',
    'administrator_help' => 'Allow user to manage users, change settings and modify all records',
    'user_create_all' => 'Create clients, invoices, etc.',
    'user_view_all' => 'View all clients, invoices, etc.',
    'user_edit_all' => 'Edit all clients, invoices, etc.',
    'gateway_help_20' => ':link to sign up for Sage Pay.',
    'gateway_help_21' => ':link to sign up for Sage Pay.',
    'partial_due' => 'Partial Due',
    'restore_vendor' => 'Restore Vendor',
    'restored_vendor' => 'Successfully restored vendor',
    'restored_expense' => 'Successfully restored expense',
    'permissions' => 'Permissions',
    'create_all_help' => 'Allow user to create and modify records',
    'view_all_help' => 'Allow user to view records they didn\'t create',
    'edit_all_help' => 'Allow user to modify records they didn\'t create',
    'view_payment' => 'View Payment',

    'january' => 'Ianuarie',
    'february' => 'Februarie',
    'march' => 'Martie',
    'april' => 'Aprilie',
    'may' => 'Mai',
    'june' => 'Iunie',
    'july' => 'Iulie',
    'august' => 'August',
    'september' => 'Septembrie',
    'october' => 'Octombrie',
    'november' => 'Noiembrie',
    'december' => 'Decembrie',

    // Documents
    'documents_header' => 'Documente:',
    'email_documents_header' => 'Documente:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Quote Documents',
    'invoice_documents' => 'Invoice Documents',
    'expense_documents' => 'Expense Documents',
    'invoice_embed_documents' => 'Embed Documents',
    'invoice_embed_documents_help' => 'Include attached images in the invoice.',
    'document_email_attachment' => 'Attach Documents',
    'ubl_email_attachment' => 'Attach UBL',
    'download_documents' => 'Download Documents (:size)',
    'documents_from_expenses' => 'From Expenses:',
    'dropzone_default_message' => 'Drop files or click to upload',
    'dropzone_default_message_disabled' => 'Uploads disabled',
    'dropzone_fallback_message' => 'Your browser does not support drag\'n\'drop file uploads.',
    'dropzone_fallback_text' => 'Please use the fallback form below to upload your files like in the olden days.',
    'dropzone_file_too_big' => 'File is too big ({{filesize}}MiB). Max filesize: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'You can\'t upload files of this type.',
    'dropzone_response_error' => 'Server responded with {{statusCode}} code.',
    'dropzone_cancel_upload' => 'Cancel upload',
    'dropzone_cancel_upload_confirmation' => 'Are you sure you want to cancel this upload?',
    'dropzone_remove_file' => 'Remove file',
    'documents' => 'Documents',
    'document_date' => 'Document Date',
    'document_size' => 'Mărime',

    'enable_client_portal' => 'Portal Client',
    'enable_client_portal_help' => 'Show/hide the client portal.',
    'enable_client_portal_dashboard' => 'Dashboard',
    'enable_client_portal_dashboard_help' => 'Show/hide the dashboard page in the client portal.',

    // Plans
    'account_management' => 'Administrare cont',
    'plan_status' => 'Plan Status',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Change Plan',
    'pending_change_to' => 'Changes To',
    'plan_changes_to' => ':plan on :date',
    'plan_term_changes_to' => ':plan (:term) on :date',
    'cancel_plan_change' => 'Cancel Change',
    'plan' => 'Plan',
    'expires' => 'Expires',
    'renews' => 'Renews',
    'plan_expired' => ':plan Plan Expired',
    'trial_expired' => ':plan Plan Trial Ended',
    'never' => 'Niciodată',
    'plan_free' => 'Gratis',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'Trial',
    'plan_term' => 'Term',
    'plan_term_monthly' => 'Lunar',
    'plan_term_yearly' => 'Anual',
    'plan_term_month' => 'Lună',
    'plan_term_year' => 'An',
    'plan_price_monthly' => '$:price/Lună',
    'plan_price_yearly' => '$:price/An',
    'updated_plan' => 'Updated plan settings',
    'plan_paid' => 'Term Started',
    'plan_started' => 'Plan Started',
    'plan_expires' => 'Plan Expires',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'One year enrollment in the Invoice Ninja Pro Plan.',
    'pro_plan_month_description' => 'One month enrollment in the Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Enterprise Plan',
    'enterprise_plan_year_description' => 'One year enrollment in the Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'One month enrollment in the Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'Credit',
    'plan_credit_description' => 'Credit for unused time',
    'plan_pending_monthly' => 'Will switch to monthly on :date',
    'plan_refunded' => 'A refund has been issued.',

    'live_preview' => 'Live Preview',
    'page_size' => 'Dimensiune Pagină',
    'live_preview_disabled' => 'Live preview has been disabled to support selected font',
    'invoice_number_padding' => 'Padding',
    'preview' => 'Previzualizare',
    'list_vendors' => 'List Vendors',
    'add_users_not_supported' => 'Upgrade to the Enterprise plan to add additional users to your account.',
    'enterprise_plan_features' => 'The Enterprise plan adds support for multiple users and file attachments, :link to see the full list of features.',
    'return_to_app' => 'Return To App',


    // Payment updates
    'refund_payment' => 'Refund Payment',
    'refund_max' => 'Max:',
    'refund' => 'Refund',
    'are_you_sure_refund' => 'Refund selected payments?',
    'status_pending' => 'Pending',
    'status_completed' => 'Completed',
    'status_failed' => 'Failed',
    'status_partially_refunded' => 'Partially Refunded',
    'status_partially_refunded_amount' => ':amount Refunded',
    'status_refunded' => 'Refunded',
    'status_voided' => 'Cancelled',
    'refunded_payment' => 'Refunded Payment',
    'activity_39' => ':user cancelled a :payment_amount payment :payment',
    'activity_40' => ':user refunded :adjustment of a :payment_amount payment :payment',
    'card_expiration' => 'Exp:&nbsp:expires',

    'card_creditcardother' => 'Necunoscut',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accept US bank transfers',
    'stripe_ach_help' => 'ACH support must also be enabled in :link.',
    'ach_disabled' => 'Another gateway is already configured for direct debit.',

    'plaid' => 'Plaid',
    'client_id' => 'Client Id',
    'secret' => 'Secret',
    'public_key' => 'Public Key',
    'plaid_optional' => '(optional)',
    'plaid_environment_help' => 'When a Stripe test key is given, Plaid\'s development environment (tartan) will be used.',
    'other_providers' => 'Other Providers',
    'country_not_supported' => 'That country is not supported.',
    'invalid_routing_number' => 'The routing number is not valid.',
    'invalid_account_number' => 'The account number is not valid.',
    'account_number_mismatch' => 'The account numbers do not match.',
    'missing_account_holder_type' => 'Please select an individual or company account.',
    'missing_account_holder_name' => 'Please enter the account holder\'s name.',
    'routing_number' => 'Routing Number',
    'confirm_account_number' => 'Confirm Account Number',
    'individual_account' => 'Individual Account',
    'company_account' => 'Company Account',
    'account_holder_name' => 'Account Holder Name',
    'add_account' => 'Add Account',
    'payment_methods' => 'Payment Methods',
    'complete_verification' => 'Complete Verification',
    'verification_amount1' => 'Amount 1',
    'verification_amount2' => 'Amount 2',
    'payment_method_verified' => 'Verification completed successfully',
    'verification_failed' => 'Verification Failed',
    'remove_payment_method' => 'Remove Payment Method',
    'confirm_remove_payment_method' => 'Are you sure you want to remove this payment method?',
    'remove' => 'Remove',
    'payment_method_removed' => 'Removed payment method.',
    'bank_account_verification_help' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement. Please enter the amounts below.',
    'bank_account_verification_next_steps' => 'We have made two deposits into your account with the description "VERIFICATION". These deposits will take 1-2 business days to appear on your statement.
        Once you have the amounts, come back to this payment methods page and click "Complete Verification" next to the account.',
    'unknown_bank' => 'Bancă Necunoscută',
    'ach_verification_delay_help' => 'You will be able to use the account after completing verification. Verification usually takes 1-2 business days.',
    'add_credit_card' => 'Adaugă Card Credit',
    'payment_method_added' => 'Metodă plată adăugată.',
    'use_for_auto_bill' => 'Use For Autobill',
    'used_for_auto_bill' => 'Autobill Payment Method',
    'payment_method_set_as_default' => 'Set Autobill payment method.',
    'activity_41' => ':payment_amount payment (:payment) failed',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'You must :link.',
    'stripe_webhook_help_link_text' => 'add this URL as an endpoint at Stripe',
    'gocardless_webhook_help_link_text' => 'add this URL as an endpoint in GoCardless',
    'payment_method_error' => 'There was an error adding your payment methd. Please try again later.',
    'notification_invoice_payment_failed_subject' => 'Payment failed for Invoice :invoice',
    'notification_invoice_payment_failed' => 'A payment made by client :client towards Invoice :invoice failed. The payment has been marked as failed and :amount has been added to the client\'s balance.',
    'link_with_plaid' => 'Link Account Instantly with Plaid',
    'link_manually' => 'Link Manually',
    'secured_by_plaid' => 'Secured by Plaid',
    'plaid_linked_status' => 'Your bank account at :bank',
    'add_payment_method' => 'Add Payment Method',
    'account_holder_type' => 'Account Holder Type',
    'ach_authorization' => 'I authorize :company to use my bank account for future payments and, if necessary, electronically credit my account to correct erroneous debits. I understand that I may cancel this authorization at any time by removing the payment method or by contacting :email.',
    'ach_authorization_required' => 'You must consent to ACH transactions.',
    'off' => 'Off',
    'opt_in' => 'Opt-in',
    'opt_out' => 'Opt-out',
    'always' => 'Always',
    'opted_out' => 'Opted out',
    'opted_in' => 'Opted in',
    'manage_auto_bill' => 'Manage Auto-bill',
    'enabled' => 'Enabled',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Enable PayPal payments through BrainTree',
    'braintree_paypal_disabled_help' => 'The PayPal gateway is processing PayPal payments',
    'braintree_paypal_help' => 'You must also :link.',
    'braintree_paypal_help_link_text' => 'link PayPal to your BrainTree account',
    'token_billing_braintree_paypal' => 'Save payment details',
    'add_paypal_account' => 'Add PayPal Account',


    'no_payment_method_specified' => 'No payment method specified',
    'chart_type' => 'Chart Type',
    'format' => 'Format',
    'import_ofx' => 'Import OFX',
    'ofx_file' => 'OFX File',
    'ofx_parse_failed' => 'Failed to parse OFX file',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Sign up with WePay',
    'use_another_provider' => 'Use another provider',
    'company_name' => 'Company Name',
    'wepay_company_name_help' => 'This will appear on client\'s credit card statements.',
    'wepay_description_help' => 'The purpose of this account.',
    'wepay_tos_agree' => 'I agree to the :link.',
    'wepay_tos_link_text' => 'WePay Terms of Service',
    'resend_confirmation_email' => 'Resend Confirmation Email',
    'manage_account' => 'Manage Account',
    'action_required' => 'Action Required',
    'finish_setup' => 'Finish Setup',
    'created_wepay_confirmation_required' => 'Please check your email and confirm your email address with WePay.',
    'switch_to_wepay' => 'Switch to WePay',
    'switch' => 'Switch',
    'restore_account_gateway' => 'Restore Gateway',
    'restored_account_gateway' => 'Successfully restored gateway',
    'united_states' => 'Statele Unite ale Americii',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Accept Debit Cards',
    'debit_cards' => 'Card Debit',

    'warn_start_date_changed' => 'The next invoice will be sent on the new start date.',
    'warn_start_date_changed_not_sent' => 'The next invoice will be created on the new start date.',
    'original_start_date' => 'Original start date',
    'new_start_date' => 'New start date',
    'security' => 'Security',
    'see_whats_new' => 'See what\'s new in v:version',
    'wait_for_upload' => 'Please wait for the document upload to complete.',
    'upgrade_for_permissions' => 'Upgrade to our Enterprise plan to enable permissions.',
    'enable_second_tax_rate' => 'Enable specifying a <b>second tax rate</b>',
    'payment_file' => 'Payment File',
    'expense_file' => 'Expense File',
    'product_file' => 'Product File',
    'import_products' => 'Import Products',
    'products_will_create' => 'products will be created',
    'product_key' => 'Produs',
    'created_products' => 'Successfully created/updated :count product(s)',
    'export_help' => 'Use JSON if you plan to import the data into Invoice Ninja.<br/>The file includes clients, products, invoices, quotes and payments.',
    'selfhost_export_help' => '<br/>We recommend using mysqldump to create a full backup.',
    'JSON_file' => 'Fișier JSON',

    'view_dashboard' => 'View Dashboard',
    'client_session_expired' => 'Session Expired',
    'client_session_expired_message' => 'Your session has expired. Please click the link in your email again.',

    'auto_bill_notification' => 'This invoice will automatically be billed to your :payment_method on file on :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'bank account',
    'auto_bill_payment_method_credit_card' => 'credit card',
    'auto_bill_payment_method_paypal' => 'Cont PayPal',
    'auto_bill_notification_placeholder' => 'This invoice will automatically be billed to your credit card on file on the due date.',
    'payment_settings' => 'Payment Settings',

    'on_send_date' => 'On send date',
    'on_due_date' => 'On due date',
    'auto_bill_ach_date_help' => 'ACH will always auto bill on the due date.',
    'warn_change_auto_bill' => 'Due to NACHA rules, changes to this invoice may prevent ACH auto bill.',

    'bank_account' => 'Cont Bancar',
    'payment_processed_through_wepay' => 'ACH payments will be processed using WePay.',
    'wepay_payment_tos_agree' => 'I agree to the WePay :terms and :privacy_policy.',
    'privacy_policy' => 'Privacy Policy',
    'wepay_payment_tos_agree_required' => 'You must agree to the WePay Terms of Service and Privacy Policy.',
    'ach_email_prompt' => 'Please enter your email address:',
    'verification_pending' => 'Verification Pending',

    'update_font_cache' => 'Please force refresh the page to update the font cache.',
    'more_options' => 'More options',
    'credit_card' => 'Card de Credit',
    'bank_transfer' => 'Transfer Bancar',
    'no_transaction_reference' => 'We did not recieve a payment transaction reference from the gateway.',
    'use_bank_on_file' => 'Use Bank on File',
    'auto_bill_email_message' => 'This invoice will automatically be billed to the payment method on file on the due date.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Added :date',
    'failed_remove_payment_method' => 'Failed to remove the payment method',
    'gateway_exists' => 'Acest procesator există deja',
    'manual_entry' => 'Manual',
    'start_of_week' => 'Prima Zi a Săptamânii',

    // Frequencies
    'freq_inactive' => 'Inactiv',
    'freq_daily' => 'Zilnic',
    'freq_weekly' => 'Săptămânal',
    'freq_biweekly' => 'Bi-Săptămânal',
    'freq_two_weeks' => 'Două Săptămâni',
    'freq_four_weeks' => 'Patru Săptămâni',
    'freq_monthly' => 'Lunar',
    'freq_three_months' => 'Trei Luni',
    'freq_four_months' => 'Patru Luni',
    'freq_six_months' => 'Șase Luni',
    'freq_annually' => 'Anual',
    'freq_two_years' => 'Doi Ani',

    // Payment types
    'payment_type_Apply Credit' => 'Apply Credit',
    'payment_type_Bank Transfer' => 'Transfer Bancar',
    'payment_type_Cash' => 'Numerar',
    'payment_type_Debit' => 'Debit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Card',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Credit Card Other',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Check',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Contabilitate & Juridic',
    'industry_Advertising' => 'Publicitate',
    'industry_Aerospace' => 'Aerospațial',
    'industry_Agriculture' => 'Agricultură',
    'industry_Automotive' => 'Automotive',
    'industry_Banking & Finance' => 'Finanțe și Bănci',
    'industry_Biotechnology' => 'Biotechnology',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Comunicații',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Defense',
    'industry_Energy' => 'Energy',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Sistem public',
    'industry_Healthcare & Life Sciences' => 'Sănătate',
    'industry_Insurance' => 'Asigurări',
    'industry_Manufacturing' => 'Manufacturing',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Non-Profit',
    'industry_Pharmaceuticals' => 'Farmaceutic',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Imobiliare',
    'industry_Restaurant & Catering' => 'Restaurant & Catering',
    'industry_Retail & Wholesale' => 'Retail & Wholesale',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Travel & Luxury',
    'industry_Other' => 'Altele',
    'industry_Photography' => 'Foto',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgia',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia and Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Camerun',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan, Province of China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croatia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cipru',
    'country_Czech Republic' => 'Czech Republic',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Danemarca',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Ethiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Faroe Islands',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finlandia',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'Franța',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germania',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Grecia',
    'country_Greenland' => 'Greenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Ungaria',
    'country_Iceland' => 'Islanda',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran, Islamic Republic of',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Irlanda',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italia',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japonia',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Lebanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Letonia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libya',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lituania',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexic',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Netherlands',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norvegia',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Polonia',
    'country_Portugal' => 'Portugalia',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russian Federation',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spania',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sweden',
    'country_Switzerland' => 'Switzerland',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turkey',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'United Kingdom',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'United States',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazilian Portuguese',
    'lang_Croatian' => 'Croatian',
    'lang_Czech' => 'Czech',
    'lang_Danish' => 'Danish',
    'lang_Dutch' => 'Dutch',
    'lang_English' => 'English',
    'lang_French' => 'French',
    'lang_French - Canada' => 'French - Canada',
    'lang_German' => 'German',
    'lang_Italian' => 'Italian',
    'lang_Japanese' => 'Japanese',
    'lang_Lithuanian' => 'Lithuanian',
    'lang_Norwegian' => 'Norwegian',
    'lang_Polish' => 'Polish',
    'lang_Spanish' => 'Spanish',
    'lang_Spanish - Spain' => 'Spanish - Spain',
    'lang_Swedish' => 'Swedish',
    'lang_Albanian' => 'Albanian',
    'lang_Greek' => 'Greek',
    'lang_English - United Kingdom' => 'English - United Kingdom',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'Slovenian',
    'lang_Finnish' => 'Finnish',
    'lang_Romanian' => 'Romanian',
    'lang_Turkish - Turkey' => 'Turkish - Turkey',
    'lang_Portuguese - Brazilian' => 'Portuguese - Brazilian',
    'lang_Portuguese - Portugal' => 'Portuguese - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Bulgarian',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Contabilitate & Juridic',
    'industry_Advertising' => 'Publicitate',
    'industry_Aerospace' => 'Aerospațial',
    'industry_Agriculture' => 'Agricultură',
    'industry_Automotive' => 'Automotive',
    'industry_Banking & Finance' => 'Finanțe și Bănci',
    'industry_Biotechnology' => 'Biotechnology',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Business Services',
    'industry_Commodities & Chemicals' => 'Commodities & Chemicals',
    'industry_Communications' => 'Comunicații',
    'industry_Computers & Hightech' => 'Computers & Hightech',
    'industry_Defense' => 'Defense',
    'industry_Energy' => 'Energy',
    'industry_Entertainment' => 'Entertainment',
    'industry_Government' => 'Sistem public',
    'industry_Healthcare & Life Sciences' => 'Sănătate',
    'industry_Insurance' => 'Asigurări',
    'industry_Manufacturing' => 'Manufacturing',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Non-Profit',
    'industry_Pharmaceuticals' => 'Farmaceutic',
    'industry_Professional Services & Consulting' => 'Professional Services & Consulting',
    'industry_Real Estate' => 'Imobiliare',
    'industry_Retail & Wholesale' => 'Retail & Wholesale',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Travel & Luxury',
    'industry_Other' => 'Altele',
    'industry_Photography' => 'Foto',

    'view_client_portal' => 'View client portal',
    'view_portal' => 'View Portal',
    'vendor_contacts' => 'Vendor Contacts',
    'all' => 'All',
    'selected' => 'Selected',
    'category' => 'Category',
    'categories' => 'Categories',
    'new_expense_category' => 'New Expense Category',
    'edit_category' => 'Edit Category',
    'archive_expense_category' => 'Archive Category',
    'expense_categories' => 'Expense Categories',
    'list_expense_categories' => 'List Expense Categories',
    'updated_expense_category' => 'Successfully updated expense category',
    'created_expense_category' => 'Successfully created expense category',
    'archived_expense_category' => 'Successfully archived expense category',
    'archived_expense_categories' => 'Successfully archived :count expense category',
    'restore_expense_category' => 'Restore expense category',
    'restored_expense_category' => 'Successfully restored expense category',
    'apply_taxes' => 'Apply taxes',
    'min_to_max_users' => ':min to :max users',
    'max_users_reached' => 'The maximum number of users has been reached.',
    'buy_now_buttons' => 'Buy Now Buttons',
    'landing_page' => 'Landing Page',
    'payment_type' => 'Payment Type',
    'form' => 'Form',
    'link' => 'Link',
    'fields' => 'Fields',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Note: the client and invoice are created even if the transaction isn\'t completed.',
    'buy_now_buttons_disabled' => 'This feature requires that a product is created and a payment gateway is configured.',
    'enable_buy_now_buttons_help' => 'Enable support for buy now buttons',
    'changes_take_effect_immediately' => 'Note: changes take effect immediately',
    'wepay_account_description' => 'Payment gateway for Invoice Ninja',
    'payment_error_code' => 'There was an error processing your payment [:code]. Please try again later.',
    'standard_fees_apply' => 'Fee: 2.9%/1.2% [Credit Card/Bank Transfer] + $0.30 per successful charge.',
    'limit_import_rows' => 'Data needs to be imported in batches of :count rows or less',
    'error_title' => 'Something went wrong',
    'error_contact_text' => 'If you\'d like help please email us at :mailaddress',
    'no_undo' => 'Warning: this can\'t be undone.',
    'no_contact_selected' => 'Alege un contact',
    'no_client_selected' => 'Alege un client',

    'gateway_config_error' => 'It may help to set new passwords or generate new API keys.',
    'payment_type_on_file' => ':type on file',
    'invoice_for_client' => 'Invoice :invoice for :client',
    'intent_not_found' => 'Sorry, I\'m not sure what you\'re asking.',
    'intent_not_supported' => 'Sorry, I\'m not able to do that.',
    'client_not_found' => 'I wasn\'t able to find the client',
    'not_allowed' => 'Sorry, you don\'t have the needed permissions',
    'bot_emailed_invoice' => 'Factura ta a fost trimisă.',
    'bot_emailed_notify_viewed' => 'I\'ll email you when it\'s viewed.',
    'bot_emailed_notify_paid' => 'I\'ll email you when it\'s paid.',
    'add_product_to_invoice' => 'Add 1 :product',
    'not_authorized' => 'Nu ești autorizat',
    'bot_get_email' => 'Hi! (wave)<br/>Thanks for trying the Invoice Ninja Bot.<br/>You need to create a free account to use this bot.<br/>Send me your account email address to get started.',
    'bot_get_code' => 'Thanks! I\'ve sent a you an email with your security code.',
    'bot_welcome' => 'That\'s it, your account is verified.<br/>',
    'email_not_found' => 'I wasn\'t able to find an available account for :email',
    'invalid_code' => 'Codul nu este corect',
    'security_code_email_subject' => 'Security code for Invoice Ninja Bot',
    'security_code_email_line1' => 'This is your Invoice Ninja Bot security code.',
    'security_code_email_line2' => 'Note: it will expire in 10 minutes.',
    'bot_help_message' => 'I currently support:<br/>• Create\update\email an invoice<br/>• List products<br/>For example:<br/><i>invoice bob for 2 tickets, set the due date to next thursday and the discount to 10 percent</i>',
    'list_products' => 'List Products',

    'include_item_taxes_inline' => 'Include <b>line item taxes in line total</b>',
    'created_quotes' => 'Successfully created :count quotes(s)',
    'limited_gateways' => 'Note: we support one credit card gateway per company.',

    'warning' => 'Warning',
    'self-update' => 'Actualizare',
    'update_invoiceninja_title' => 'Actualizează Invoice Ninja',
    'update_invoiceninja_warning' => 'Before start upgrading Invoice Ninja create a backup of your database and files!',
    'update_invoiceninja_available' => 'A new version of Invoice Ninja is available.',
    'update_invoiceninja_unavailable' => 'No new version of Invoice Ninja available.',
    'update_invoiceninja_instructions' => 'Please install the new version <strong>:version</strong> by clicking the <em>Update now</em> button below. Afterwards you\'ll be redirected to the dashboard.',
    'update_invoiceninja_update_start' => 'Actualizează acum',
    'update_invoiceninja_download_start' => 'Descarcă :version',
    'create_new' => 'Create New',

    'toggle_navigation' => 'Toggle Navigation',
    'toggle_history' => 'Toggle History',
    'unassigned' => 'Unassigned',
    'task' => 'Task',
    'contact_name' => 'Contact Name',
    'city_state_postal' => 'City/State/Postal',
    'custom_field' => 'Custom Field',
    'account_fields' => 'Company Fields',
    'facebook_and_twitter' => 'Facebook and Twitter',
    'facebook_and_twitter_help' => 'Follow our feeds to help support our project',
    'reseller_text' => 'Note: the white-label license is intended for personal use, please email us at :email if you\'d like to resell the app.',
    'unnamed_client' => 'Unnamed Client',

    'day' => 'Zi',
    'week' => 'Săptămână',
    'month' => 'Lună',
    'inactive_logout' => 'You have been logged out due to inactivity',
    'reports' => 'Reports',
    'total_profit' => 'Profit Total',
    'total_expenses' => 'Total Expenses',
    'quote_to' => 'Quote to',

    // Limits
    'limit' => 'Limit',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'No Limits',
    'set_limits' => 'Set :gateway_type Limits',
    'enable_min' => 'Enable min',
    'enable_max' => 'Enable max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'This invoice does not meet the limits for that payment type.',

    'date_range' => 'Date Range',
    'raw' => 'Raw',
    'raw_html' => 'Raw HTML',
    'update' => 'Actualizează',
    'invoice_fields_help' => 'Drag and drop fields to change their order and location',
    'new_category' => 'Categorie Nouă',
    'restore_product' => 'Restore Product',
    'blank' => 'Blank',
    'invoice_save_error' => 'There was an error saving your invoice',
    'enable_recurring' => 'Enable Recurring',
    'disable_recurring' => 'Disable Recurring',
    'text' => 'Text',
    'expense_will_create' => 'expense will be created',
    'expenses_will_create' => 'expenses will be created',
    'created_expenses' => 'Successfully created :count expense(s)',

    'translate_app' => 'Help improve our translations with :link',
    'expense_category' => 'Expense Category',

    'go_ninja_pro' => 'Go Ninja Pro!',
    'go_enterprise' => 'Go Enterprise!',
    'upgrade_for_features' => 'Upgrade For More Features',
    'pay_annually_discount' => 'Pay annually for 10 months + 2 free!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Customize every aspect of your invoice!',
    'enterprise_upgrade_feature1' => 'Set permissions for multiple-users',
    'enterprise_upgrade_feature2' => 'Attach 3rd party files to invoices & expenses',
    'much_more' => 'Much More!',
    'all_pro_fetaures' => 'Plus all pro features!',

    'currency_symbol' => 'Symbol',
    'currency_code' => 'Code',

    'buy_license' => 'Cumpără Licență',
    'apply_license' => 'Aplică Licență',
    'submit' => 'Submit',
    'white_label_license_key' => 'License Key',
    'invalid_white_label_license' => 'The white label license is not valid',
    'created_by' => 'Created by :name',
    'modules' => 'Modules',
    'financial_year_start' => 'Prima Lună din An',
    'authentication' => 'Authentication',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Semnătură',
    'show_accept_invoice_terms' => 'Invoice Terms Checkbox',
    'show_accept_invoice_terms_help' => 'Require client to confirm that they accept the invoice terms.',
    'show_accept_quote_terms' => 'Quote Terms Checkbox',
    'show_accept_quote_terms_help' => 'Require client to confirm that they accept the quote terms.',
    'require_invoice_signature' => 'Invoice Signature',
    'require_invoice_signature_help' => 'Require client to provide their signature.',
    'require_quote_signature' => 'Quote Signature',
    'require_quote_signature_help' => 'Require client to provide their signature.',
    'i_agree' => 'I Agree To The Terms',
    'sign_here' => 'Please sign here:',
    'authorization' => 'Authorization',
    'signed' => 'Semnat',

    // BlueVine
    'bluevine_promo' => 'Get flexible business lines of credit and invoice factoring using BlueVine.',
    'bluevine_modal_label' => 'Sign up with BlueVine',
    'bluevine_modal_text' => '<h3>Fast funding for your business. No paperwork.</h3>
<ul><li>Flexible business lines of credit and invoice factoring.</li></ul>',
    'bluevine_create_account' => 'Create an account',
    'quote_types' => 'Get a quote for',
    'invoice_factoring' => 'Invoice factoring',
    'line_of_credit' => 'Line of credit',
    'fico_score' => 'Your FICO score',
    'business_inception' => 'Business Inception Date',
    'average_bank_balance' => 'Average bank account balance',
    'annual_revenue' => 'Annual revenue',
    'desired_credit_limit_factoring' => 'Desired invoice factoring limit',
    'desired_credit_limit_loc' => 'Desired line of credit limit',
    'desired_credit_limit' => 'Desired credit limit',
    'bluevine_credit_line_type_required' => 'You must choose at least one',
    'bluevine_field_required' => 'This field is required',
    'bluevine_unexpected_error' => 'An unexpected error occurred.',
    'bluevine_no_conditional_offer' => 'More information is required before getting a quote. Click continue below.',
    'bluevine_invoice_factoring' => 'Invoice Factoring',
    'bluevine_conditional_offer' => 'Conditional Offer',
    'bluevine_credit_line_amount' => 'Credit Line',
    'bluevine_advance_rate' => 'Advance Rate',
    'bluevine_weekly_discount_rate' => 'Weekly Discount Rate',
    'bluevine_minimum_fee_rate' => 'Minimum Fee',
    'bluevine_line_of_credit' => 'Line of Credit',
    'bluevine_interest_rate' => 'Interest Rate',
    'bluevine_weekly_draw_rate' => 'Weekly Draw Rate',
    'bluevine_continue' => 'Continue to BlueVine',
    'bluevine_completed' => 'BlueVine signup completed',

    'vendor_name' => 'Vendor',
    'entity_state' => 'State',
    'client_created_at' => 'Date Created',
    'postmark_error' => 'There was a problem sending the email through Postmark: :link',
    'project' => 'Proiect',
    'projects' => 'Proiecte',
    'new_project' => 'Proiect nou',
    'edit_project' => 'Editează Proiect',
    'archive_project' => 'Arhivează Proiect',
    'list_projects' => 'List Projects',
    'updated_project' => 'Successfully updated project',
    'created_project' => 'Successfully created project',
    'archived_project' => 'Successfully archived project',
    'archived_projects' => 'Successfully archived :count projects',
    'restore_project' => 'Restaurează Proiect',
    'restored_project' => 'Successfully restored project',
    'delete_project' => 'Delete Project',
    'deleted_project' => 'Successfully deleted project',
    'deleted_projects' => 'Successfully deleted :count projects',
    'delete_expense_category' => 'Delete category',
    'deleted_expense_category' => 'Successfully deleted category',
    'delete_product' => 'Delete Product',
    'deleted_product' => 'Successfully deleted product',
    'deleted_products' => 'Successfully deleted :count products',
    'restored_product' => 'Successfully restored product',
    'update_credit' => 'Update Credit',
    'updated_credit' => 'Successfully updated credit',
    'edit_credit' => 'Edit Credit',
    'realtime_preview' => 'Realtime Preview',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => 'Replace the built-in PDF viewer in :chrome_link and :firefox_link.<br/>Enable this if your browser is automatically downloading the PDF.',
    'force_pdfjs' => 'Prevent Download',
    'redirect_url' => 'Redirect URL',
    'redirect_url_help' => 'Optionally specify a URL to redirect to after a payment is entered.',
    'save_draft' => 'Save Draft',
    'refunded_credit_payment' => 'Refunded credit payment',
    'keyboard_shortcuts' => 'Keyboard Shortcuts',
    'toggle_menu' => 'Toggle Menu',
    'new_...' => 'New ...',
    'list_...' => 'List ...',
    'created_at' => 'Date Created',
    'contact_us' => 'Contact Us',
    'user_guide' => 'User Guide',
    'promo_message' => 'Upgrade before :expires and get :amount OFF your first year of our Pro or Enterprise packages.',
    'discount_message' => ':amount off expires :expires',
    'mark_paid' => 'Mark Paid',
    'marked_sent_invoice' => 'Successfully marked invoice sent',
    'marked_sent_invoices' => 'Successfully marked invoices sent',
    'invoice_name' => 'Invoice',
    'product_will_create' => 'product will be created',
    'contact_us_response' => 'Thank you for your message! We\'ll try to respond as soon as possible.',
    'last_7_days' => 'Ultimele 7 Zile',
    'last_30_days' => 'Ultimele 30 Zile',
    'this_month' => 'Luna curentă',
    'last_month' => 'Luna trecută',
    'current_quarter' => 'Current Quarter',
    'last_quarter' => 'Last Quarter',
    'last_year' => 'Anul Trecut',
    'custom_range' => 'Custom Range',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Require',
    'license_expiring' => 'Note: Your license will expire in :count days, :link to renew it.',
    'security_confirmation' => 'Your email address has been confirmed.',
    'white_label_expired' => 'Your white label license has expired, please consider renewing it to help support our project.',
    'renew_license' => 'Reînnoiește Licența',
    'iphone_app_message' => 'Consider downloading our :link',
    'iphone_app' => 'iPhone app',
    'android_app' => 'Android app',
    'logged_in' => 'Logged In',
    'switch_to_primary' => 'Switch to your primary company (:name) to manage your plan.',
    'inclusive' => 'Inclusive',
    'exclusive' => 'Exclusive',
    'postal_city_state' => 'Postal/City/State',
    'phantomjs_help' => 'In certain cases the app uses :link_phantom to generate the PDF, install :link_docs to generate it locally.',
    'phantomjs_local' => 'Using local PhantomJS',
    'client_number' => 'Client Number',
    'client_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the client number.',
    'next_client_number' => 'The next client number is :number.',
    'generated_numbers' => 'Generated Numbers',
    'notes_reminder1' => 'Prima Notificare',
    'notes_reminder2' => 'A Doua Notificare',
    'notes_reminder3' => 'A Treia Notificare',
    'notes_reminder4' => 'Reminder',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'Tax Quote',
    'tax_invoice' => 'Tax Invoice',
    'emailed_invoices' => 'Successfully emailed invoices',
    'emailed_quotes' => 'Successfully emailed quotes',
    'website_url' => 'Website URL',
    'domain' => 'Domain',
    'domain_help' => 'Used in the client portal and when sending emails.',
    'domain_help_website' => 'Used when sending emails.',
    'import_invoices' => 'Importa Facturi',
    'new_report' => 'New Report',
    'edit_report' => 'Edit Report',
    'columns' => 'Columns',
    'filters' => 'Filters',
    'sort_by' => 'Sort By',
    'draft' => 'Draft',
    'unpaid' => 'Unpaid',
    'aging' => 'Aging',
    'age' => 'Age',
    'days' => 'Days',
    'age_group_0' => '0 - 30 Days',
    'age_group_30' => '30 - 60 Days',
    'age_group_60' => '60 - 90 Days',
    'age_group_90' => '90 - 120 Days',
    'age_group_120' => '120+ Days',
    'invoice_details' => 'Invoice Details',
    'qty' => 'Quantity',
    'profit_and_loss' => 'Profit și Pierdere',
    'revenue' => 'Revenue',
    'profit' => 'Profit',
    'group_when_sorted' => 'Group Sort',
    'group_dates_by' => 'Group Dates By',
    'year' => 'An',
    'view_statement' => 'Vezi Extras',
    'statement' => 'Extras',
    'statement_date' => 'Dată Extras',
    'mark_active' => 'Mark Active',
    'send_automatically' => 'Trimite Automat',
    'initial_email' => 'Initial Email',
    'invoice_not_emailed' => 'This invoice hasn\'t been emailed.',
    'quote_not_emailed' => 'This quote hasn\'t been emailed.',
    'sent_by' => 'Sent by :user',
    'recipients' => 'Recipients',
    'save_as_default' => 'Save as default',
    'start_of_week_help' => 'Used by <b>date</b> selectors',
    'financial_year_start_help' => 'Used by <b>date range</b> selectors',
    'reports_help' => 'Shift + Click to sort by multiple columns, Ctrl + Click to clear the grouping.',
    'this_year' => 'Anul Curent',

    // Updated login screen
    'ninja_tagline' => 'Create. Send. Get Paid.',
    'login_or_existing' => 'Or login with a connected account.',
    'sign_up_now' => 'Sign Up Now',
    'not_a_member_yet' => 'Not a member yet?',
    'login_create_an_account' => 'Create an Account!',

    // New Client Portal styling
    'invoice_from' => 'Invoices From:',
    'email_alias_message' => 'We require each company to have a unique email address.<br/>Consider using an alias. ie, email+label@example.com',
    'full_name' => 'Full Name',
    'month_year' => 'LUNĂ/AN',
    'valid_thru' => 'Valid\nthru',

    'product_fields' => 'Product Fields',
    'custom_product_fields_help' => 'Add a field when creating a product or invoice and display the label and value on the PDF.',
    'freq_two_months' => 'Două Luni',
    'freq_yearly' => 'Anual',
    'profile' => 'Profil',
    'payment_type_help' => 'Sets the default <b>manual payment type</b>.',
    'industry_Construction' => 'Construction',
    'your_statement' => 'Your Statement',
    'statement_issued_to' => 'Statement issued to',
    'statement_to' => 'Statement to',
    'customize_options' => 'Customize options',
    'created_payment_term' => 'Successfully created payment term',
    'updated_payment_term' => 'Successfully updated payment term',
    'archived_payment_term' => 'Successfully archived payment term',
    'resend_invite' => 'Resend Invitation',
    'credit_created_by' => 'Credit created by payment :transaction_reference',
    'created_payment_and_credit' => 'Successfully created payment and credit',
    'created_payment_and_credit_emailed_client' => 'Successfully created payment and credit, and emailed client',
    'create_project' => 'Create project',
    'create_vendor' => 'Create vendor',
    'create_expense_category' => 'Create category',
    'pro_plan_reports' => ':link to enable reports by joining the Pro Plan',
    'mark_ready' => 'Mark Ready',

    'limits' => 'Limits',
    'fees' => 'Fees',
    'fee' => 'Fee',
    'set_limits_fees' => 'Set :gateway_type Limits/Fees',
    'fees_tax_help' => 'Enable line item taxes to set the fee tax rates.',
    'fees_sample' => 'The fee for a :amount invoice would be :total.',
    'discount_sample' => 'The discount for a :amount invoice would be :total.',
    'no_fees' => 'No Fees',
    'gateway_fees_disclaimer' => 'Warning: not all states/payment gateways allow adding fees, please review local laws/terms of service.',
    'percent' => 'Percent',
    'location' => 'Location',
    'line_item' => 'Line Item',
    'surcharge' => 'Surcharge',
    'location_first_surcharge' => 'Enabled - First surcharge',
    'location_second_surcharge' => 'Enabled - Second surcharge',
    'location_line_item' => 'Enabled - Line item',
    'online_payment_surcharge' => 'Online Payment Surcharge',
    'gateway_fees' => 'Gateway Fees',
    'fees_disabled' => 'Fees are disabled',
    'gateway_fees_help' => 'Automatically add an online payment surcharge/discount.',
    'gateway' => 'Gateway',
    'gateway_fee_change_warning' => 'If there are unpaid invoices with fees they need to be updated manually.',
    'fees_surcharge_help' => 'Customize surcharge :link.',
    'label_and_taxes' => 'label and taxes',
    'billable' => 'Billable',
    'logo_warning_too_large' => 'The image file is too large.',
    'logo_warning_fileinfo' => 'Warning: To support gifs the fileinfo PHP extension needs to be enabled.',
    'logo_warning_invalid' => 'There was a problem reading the image file, please try a different format.',

    'error_refresh_page' => 'An error occurred, please refresh the page and try again.',
    'data' => 'Data',
    'imported_settings' => 'Successfully imported settings',
    'reset_counter' => 'Reset Counter',
    'next_reset' => 'Next Reset',
    'reset_counter_help' => 'Automatically reset the invoice and quote counters.',
    'auto_bill_failed' => 'Auto-billing for invoice :invoice_number failed',
    'online_payment_discount' => 'Online Payment Discount',
    'created_new_company' => 'Successfully created new company',
    'fees_disabled_for_gateway' => 'Fees are disabled for this gateway.',
    'logout_and_delete' => 'Log Out/Delete Account',
    'tax_rate_type_help' => 'Inclusive tax rates adjust the line item cost when selected.<br/>Only exclusive tax rates can be used as a default.',
    'invoice_footer_help' => 'Use $pageNumber and $pageCount to display the page information.',
    'credit_note' => 'Credit Note',
    'credit_issued_to' => 'Credit issued to',
    'credit_to' => 'Credit to',
    'your_credit' => 'Your Credit',
    'credit_number' => 'Credit Number',
    'create_credit_note' => 'Create Credit Note',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Error: The gateways table has incorrect ids.',
    'purge_data' => 'Purge Data',
    'delete_data' => 'Delete Data',
    'purge_data_help' => 'Permanently delete all data but keep the account and settings.',
    'cancel_account_help' => 'Permanently delete the account along with all data and setting.',
    'purge_successful' => 'Successfully purged company data',
    'forbidden' => 'Forbidden',
    'purge_data_message' => 'Warning: This will permanently erase your data, there is no undo.',
    'contact_phone' => 'Contact Phone',
    'contact_email' => 'Contact Email',
    'reply_to_email' => 'Reply-To Email',
    'reply_to_email_help' => 'Specify the reply-to address for client emails.',
    'bcc_email_help' => 'Privately include this address with client emails.',
    'import_complete' => 'Your import has successfully completed.',
    'confirm_account_to_import' => 'Please confirm your account to import data.',
    'import_started' => 'Your import has started, we\'ll send you an email once it completes.',
    'listening' => 'Listening...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Voice Commands',
    'sample_commands' => 'Sample commands',
    'voice_commands_feedback' => 'We\'re actively working to improve this feature, if there\'s a command you\'d like us to support please email us at :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'Successfully archived :count products',
    'recommend_on' => 'We recommend <b>enabling</b> this setting.',
    'recommend_off' => 'We recommend <b>disabling</b> this setting.',
    'notes_auto_billed' => 'Auto-billed',
    'surcharge_label' => 'Surcharge Label',
    'contact_fields' => 'Contact Fields',
    'custom_contact_fields_help' => 'Add a field when creating a contact and optionally display the label and value on the PDF.',
    'datatable_info' => 'Showing :start to :end of :total entries',
    'credit_total' => 'Credit Total',
    'mark_billable' => 'Mark billable',
    'billed' => 'Billed',
    'company_variables' => 'Company Variables',
    'client_variables' => 'Client Variables',
    'invoice_variables' => 'Invoice Variables',
    'navigation_variables' => 'Navigation Variables',
    'custom_variables' => 'Custom Variables',
    'invalid_file' => 'Invalid file type',
    'add_documents_to_invoice' => 'Add documents to invoice',
    'mark_expense_paid' => 'Mark paid',
    'white_label_license_error' => 'Failed to validate the license, check storage/logs/laravel-error.log for more details.',
    'plan_price' => 'Plan Price',
    'wrong_confirmation' => 'Incorrect confirmation code',
    'oauth_taken' => 'The account is already registered',
    'emailed_payment' => 'Successfully emailed payment',
    'email_payment' => 'Email Payment',
    'invoiceplane_import' => 'Use :link to migrate your data from InvoicePlane.',
    'duplicate_expense_warning' => 'Warning: This :link may be a duplicate',
    'expense_link' => 'expense',
    'resume_task' => 'Resume Task',
    'resumed_task' => 'Successfully resumed task',
    'quote_design' => 'Quote Design',
    'default_design' => 'Standard Design',
    'custom_design1' => 'Custom Design 1',
    'custom_design2' => 'Custom Design 2',
    'custom_design3' => 'Custom Design 3',
    'empty' => 'Empty',
    'load_design' => 'Load Design',
    'accepted_card_logos' => 'Accepted Card Logos',
    'phantomjs_local_and_cloud' => 'Using local PhantomJS, falling back to phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Track payments using :link',
    'start_date_required' => 'The start date is required',
    'application_settings' => 'Application Settings',
    'database_connection' => 'Database Connection',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'Test connection',
    'from_name' => 'From Name',
    'from_address' => 'From Address',
    'port' => 'Port',
    'encryption' => 'Encryption',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Send test email',
    'select_label' => 'Select Label',
    'label' => 'Label',
    'service' => 'Service',
    'update_payment_details' => 'Update payment details',
    'updated_payment_details' => 'Successfully updated payment details',
    'update_credit_card' => 'Update Credit Card',
    'recurring_expenses' => 'Recurring Expenses',
    'recurring_expense' => 'Recurring Expense',
    'new_recurring_expense' => 'New Recurring Expense',
    'edit_recurring_expense' => 'Edit Recurring Expense',
    'archive_recurring_expense' => 'Archive Recurring Expense',
    'list_recurring_expense' => 'List Recurring Expenses',
    'updated_recurring_expense' => 'Successfully updated recurring expense',
    'created_recurring_expense' => 'Successfully created recurring expense',
    'archived_recurring_expense' => 'Successfully archived recurring expense',
    'restore_recurring_expense' => 'Restore Recurring Expense',
    'restored_recurring_expense' => 'Successfully restored recurring expense',
    'delete_recurring_expense' => 'Delete Recurring Expense',
    'deleted_recurring_expense' => 'Successfully deleted project',
    'view_recurring_expense' => 'View Recurring Expense',
    'taxes_and_fees' => 'Taxes and fees',
    'import_failed' => 'Import Failed',
    'recurring_prefix' => 'Recurring Prefix',
    'options' => 'Options',
    'credit_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the credit number for negative invoices.',
    'next_credit_number' => 'The next credit number is :number.',
    'padding_help' => 'The number of zero\'s to pad the number.',
    'import_warning_invalid_date' => 'Warning: The date format appears to be invalid.',
    'product_notes' => 'Product Notes',
    'app_version' => 'App Version',
    'ofx_version' => 'OFX Version',
    'gateway_help_23' => ':link to get your Stripe API keys.',
    'error_app_key_set_to_default' => 'Error: APP_KEY is set to a default value, to update it backup your database and then run <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Charge Late Fee',
    'late_fee_amount' => 'Late Fee Amount',
    'late_fee_percent' => 'Late Fee Percent',
    'late_fee_added' => 'Late fee added on :date',
    'download_invoice' => 'Download Invoice',
    'download_quote' => 'Download Quote',
    'invoices_are_attached' => 'Your invoice PDFs are attached.',
    'downloaded_invoice' => 'An email will be sent with the invoice PDF',
    'downloaded_quote' => 'An email will be sent with the quote PDF',
    'downloaded_invoices' => 'An email will be sent with the invoice PDFs',
    'downloaded_quotes' => 'An email will be sent with the quote PDFs',
    'clone_expense' => 'Clone Expense',
    'default_documents' => 'Default Documents',
    'send_email_to_client' => 'Send email to the client',
    'refund_subject' => 'Refund Processed',
    'refund_body' => 'You have been processed a refund of :amount for invoice :invoice_number.',

    'currency_us_dollar' => 'US Dollar',
    'currency_british_pound' => 'British Pound',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danish Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing a review',

    'use_english_version' => 'Make sure to use the English version of the files.<br/>We use the column headers to match the fields.',
    'tax1' => 'First Tax',
    'tax2' => 'Second Tax',
    'fee_help' => 'Gateway fees are the costs charged for access to the financial networks that handle the processing of online payments.',
    'format_export' => 'Exporting format',
    'custom1' => 'First Custom',
    'custom2' => 'Second Custom',
    'contact_first_name' => 'Contact First Name',
    'contact_last_name' => 'Contact Last Name',
    'contact_custom1' => 'Contact First Custom',
    'contact_custom2' => 'Contact Second Custom',
    'currency' => 'Currency',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'comments',

    'item_product' => 'Item Product',
    'item_notes' => 'Item Notes',
    'item_cost' => 'Item Cost',
    'item_quantity' => 'Item Quantity',
    'item_tax_rate' => 'Item Tax Rate',
    'item_tax_name' => 'Item Tax Name',
    'item_tax1' => 'Item Tax1',
    'item_tax2' => 'Item Tax2',

    'delete_company' => 'Delete Company',
    'delete_company_help' => 'Permanently delete the company along with all data and setting.',
    'delete_company_message' => 'Warning: This will permanently delete your company, there is no undo.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Include Errors',
    'include_errors_help' => 'Include :link from storage/logs/laravel-error.log',
    'recent_errors' => 'recent errors',
    'customer' => 'Customer',
    'customers' => 'Customers',
    'created_customer' => 'Successfully created customer',
    'created_customers' => 'Successfully created :count customers',

    'purge_details' => 'The data in your company (:account) has been successfully purged.',
    'deleted_company' => 'Successfully deleted company',
    'deleted_account' => 'Successfully canceled account',
    'deleted_company_details' => 'Your company (:account) has been successfully deleted.',
    'deleted_account_details' => 'Your account (:account) has been successfully deleted.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Accept Alipay',
    'enable_sofort' => 'Accept EU bank transfers',
    'stripe_alipay_help' => 'These gateways also need to be activated in :link.',
    'calendar' => 'Calendar',
    'pro_plan_calendar' => ':link to enable the calendar by joining the Pro Plan',

    'what_are_you_working_on' => 'What are you working on?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Refresh',
    'filter_sort' => 'Filter/Sort',
    'no_description' => 'No Description',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Save or discard your changes',
    'discard_changes' => 'Discard Changes',
    'tasks_not_enabled' => 'Tasks are not enabled.',
    'started_task' => 'Successfully started task',
    'create_client' => 'Create Client',

    'download_desktop_app' => 'Download the desktop app',
    'download_iphone_app' => 'Download the iPhone app',
    'download_android_app' => 'Download the Android app',
    'time_tracker_mobile_help' => 'Double tap a task to select it',
    'stopped' => 'Stopped',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
    'sort_field' => 'Sort By',
    'sort_direction' => 'Direction',
    'discard' => 'Discard',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Note: accepting online payments requires a payment gateway, :link to add one.',
    'task_rate' => 'Task Rate',
    'task_rate_help' => 'Set the default rate for invoiced tasks.',
    'past_due' => 'Past Due',
    'document' => 'Document',
    'invoice_or_expense' => 'Invoice/Expense',
    'invoice_pdfs' => 'Invoice PDFs',
    'enable_sepa' => 'Accept SEPA',
    'enable_bitcoin' => 'Accept Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing your IBAN and confirming this payment, you are authorizing :company and Stripe, our payment service provider, to send instructions to your bank to debit your account and your bank to debit your account in accordance with those instructions. You are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited.',
    'recover_license' => 'Recover License',
    'purchase' => 'Purchase',
    'recover' => 'Recover',
    'apply' => 'Apply',
    'recover_white_label_header' => 'Recover White Label License',
    'apply_white_label_header' => 'Apply White Label License',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Return to Invoice',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Partial Due Date',
    'task_fields' => 'Task Fields',
    'product_fields_help' => 'Drag and drop fields to change their order',
    'custom_value1' => 'Custom Value',
    'custom_value2' => 'Custom Value',
    'enable_two_factor' => 'Two-Factor Authentication',
    'enable_two_factor_help' => 'Use your phone to confirm your identity when logging in',
    'two_factor_setup' => 'Two-Factor Setup',
    'two_factor_setup_help' => 'Scan the bar code with a :link compatible app.',
    'one_time_password' => 'One Time Password',
    'set_phone_for_two_factor' => 'Set your mobile phone number as a backup to enable.',
    'enabled_two_factor' => 'Successfully enabled Two-Factor Authentication',
    'add_product' => 'Add Product',
    'email_will_be_sent_on' => 'Note: the email will be sent on :date.',
    'invoice_product' => 'Invoice Product',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: local storage is not available.',
    'your_password_reset_link' => 'Your Password Reset Link',
    'subdomain_taken' => 'The subdomain is already in use',
    'client_login' => 'Client Login',
    'converted_amount' => 'Converted Amount',
    'default' => 'Default',
    'shipping_address' => 'Shipping Address',
    'bllling_address' => 'Billing Address',
    'billing_address1' => 'Billing Street',
    'billing_address2' => 'Billing Apt/Suite',
    'billing_city' => 'Billing City',
    'billing_state' => 'Billing State/Province',
    'billing_postal_code' => 'Billing Postal Code',
    'billing_country' => 'Billing Country',
    'shipping_address1' => 'Shipping Street',
    'shipping_address2' => 'Shipping Apt/Suite',
    'shipping_city' => 'Shipping City',
    'shipping_state' => 'Shipping State/Province',
    'shipping_postal_code' => 'Shipping Postal Code',
    'shipping_country' => 'Shipping Country',
    'classify' => 'Classify',
    'show_shipping_address_help' => 'Require client to provide their shipping address',
    'ship_to_billing_address' => 'Ship to billing address',
    'delivery_note' => 'Delivery Note',
    'show_tasks_in_portal' => 'Show tasks in the client portal',
    'cancel_schedule' => 'Cancel Schedule',
    'scheduled_report' => 'Scheduled Report',
    'scheduled_report_help' => 'Email the :report report as :format to :email',
    'created_scheduled_report' => 'Successfully scheduled report',
    'deleted_scheduled_report' => 'Successfully canceled scheduled report',
    'scheduled_report_attached' => 'Your scheduled :type report is attached.',
    'scheduled_report_error' => 'Failed to create schedule report',
    'invalid_one_time_password' => 'Invalid one time password',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accept Apple Pay and Pay with Google',
    'requires_subdomain' => 'This payment type requires that a :link.',
    'subdomain_is_set' => 'subdomain is set',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'The verification file is needed to accept payments.',
    'apple_pay_domain' => 'Use <code>:domain</code> as the domain in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay isn\'t supported by your browser',
    'optional_payment_methods' => 'Optional Payment Methods',
    'add_subscription' => 'Add Subscription',
    'target_url' => 'Target',
    'target_url_help' => 'When the selected event occurs the app will post the entity to the target URL.',
    'event' => 'Event',
    'subscription_event_1' => 'Created Client',
    'subscription_event_2' => 'Created Invoice',
    'subscription_event_3' => 'Created Quote',
    'subscription_event_4' => 'Created Payment',
    'subscription_event_5' => 'Created Vendor',
    'subscription_event_6' => 'Updated Quote',
    'subscription_event_7' => 'Deleted Quote',
    'subscription_event_8' => 'Updated Invoice',
    'subscription_event_9' => 'Deleted Invoice',
    'subscription_event_10' => 'Updated Client',
    'subscription_event_11' => 'Deleted Client',
    'subscription_event_12' => 'Deleted Payment',
    'subscription_event_13' => 'Updated Vendor',
    'subscription_event_14' => 'Deleted Vendor',
    'subscription_event_15' => 'Created Expense',
    'subscription_event_16' => 'Updated Expense',
    'subscription_event_17' => 'Deleted Expense',
    'subscription_event_18' => 'Created Task',
    'subscription_event_19' => 'Updated Task',
    'subscription_event_20' => 'Deleted Task',
    'subscription_event_21' => 'Approved Quote',
    'subscriptions' => 'Subscriptions',
    'updated_subscription' => 'Successfully updated subscription',
    'created_subscription' => 'Successfully created subscription',
    'edit_subscription' => 'Edit Subscription',
    'archive_subscription' => 'Archive Subscription',
    'archived_subscription' => 'Successfully archived subscription',
    'project_error_multiple_clients' => 'The projects can\'t belong to different clients',
    'invoice_project' => 'Invoice Project',
    'module_recurring_invoice' => 'Recurring Invoices',
    'module_credit' => 'Credits',
    'module_quote' => 'Quotes & Proposals',
    'module_task' => 'Tasks & Projects',
    'module_expense' => 'Expenses & Vendors',
    'module_ticket' => 'Tickets',
    'reminders' => 'Reminders',
    'send_client_reminders' => 'Send email reminders',
    'can_view_tasks' => 'Tasks are visible in the portal',
    'is_not_sent_reminders' => 'Reminders are not sent',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Please register your account',
    'processing_request' => 'Processing request',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Edit Times',
    'inclusive_taxes_help' => 'Include <b>taxes in the cost</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Copy Shipping',
    'copy_billing' => 'Copy Billing',
    'quote_has_expired' => 'The quote has expired, please contact the merchant.',
    'empty_table_footer' => 'Showing 0 to 0 of 0 entries',
    'do_not_trust' => 'Do not remember this device',
    'trust_for_30_days' => 'Trust for 30 days',
    'trust_forever' => 'Trust forever',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'In progress',
    'add_status' => 'Add status',
    'archive_status' => 'Archive Status',
    'new_status' => 'New Status',
    'convert_products' => 'Convert Products',
    'convert_products_help' => 'Automatically convert product prices to the client\'s currency',
    'improve_client_portal_link' => 'Set a subdomain to shorten the client portal link.',
    'budgeted_hours' => 'Budgeted Hours',
    'progress' => 'Progress',
    'view_project' => 'View Project',
    'summary' => 'Summary',
    'endless_reminder' => 'Endless Reminder',
    'signature_on_invoice_help' => 'Add the following code to show your client\'s signature on the PDF.',
    'signature_on_pdf' => 'Show on PDF',
    'signature_on_pdf_help' => 'Show the client signature on the invoice/quote PDF.',
    'expired_white_label' => 'The white label license has expired',
    'return_to_login' => 'Return to Login',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Use <code>Label|Option1,Option2</code> to show a select box.',
    'client_information' => 'Client Information',
    'updated_client_details' => 'Successfully updated client details',
    'auto' => 'Auto',
    'tax_amount' => 'Tax Amount',
    'tax_paid' => 'Tax Paid',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Proposal',
    'proposals' => 'Proposals',
    'list_proposals' => 'List Proposals',
    'new_proposal' => 'New Proposal',
    'edit_proposal' => 'Edit Proposal',
    'archive_proposal' => 'Archive Proposal',
    'delete_proposal' => 'Delete Proposal',
    'created_proposal' => 'Successfully created proposal',
    'updated_proposal' => 'Successfully updated proposal',
    'archived_proposal' => 'Successfully archived proposal',
    'deleted_proposal' => 'Successfully archived proposal',
    'archived_proposals' => 'Successfully archived :count proposals',
    'deleted_proposals' => 'Successfully archived :count proposals',
    'restored_proposal' => 'Successfully restored proposal',
    'restore_proposal' => 'Restore Proposal',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Șablon',
    'templates' => 'Templates',
    'proposal_template' => 'Template',
    'proposal_templates' => 'Templates',
    'new_proposal_template' => 'New Template',
    'edit_proposal_template' => 'Edit Template',
    'archive_proposal_template' => 'Archive Template',
    'delete_proposal_template' => 'Delete Template',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Restore Template',
    'proposal_category' => 'Category',
    'proposal_categories' => 'Categories',
    'new_proposal_category' => 'New Category',
    'edit_proposal_category' => 'Edit Category',
    'archive_proposal_category' => 'Archive Category',
    'delete_proposal_category' => 'Delete Category',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'The requested proposal is not available',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'Proposal Email',
    'proposal_subject' => 'New proposal :number from :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Successfully emailed proposal',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Email address has been changed',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'No messages found',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Clone Product',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'View Proposal',
    'view_in_portal' => 'View in Portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Import Vendors',
    'company' => 'Company',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Product Field',
    'task_field' => 'Task Field',
    'project_field' => 'Project Field',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Vendor Field',
    'company_field' => 'Company Field',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Add a field when creating a project.',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Add a field when creating a vendor.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Show Payments',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'All Invoices',
    'my_invoices' => 'My Invoices',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Maximum',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Reactualizeaza datele',
    'blank_contact' => 'Contact gol',
    'no_records_found' => 'Nu exista inregistrari',
    'industry' => 'Industrie',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Arata sarcini
',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Trimite',
    'auto_billing' => 'Auto billing',
    'button' => 'Buton',
    'more' => 'More',
    'edit_recurring_invoice' => 'Editare factura recurenta',
    'edit_recurring_quote' => 'Editare oferta recurenta',
    'quote_status' => 'Status oferta',
    'please_select_an_invoice' => 'Te rugam selecteaza o oferta',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Status plata',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'Vizualizare tichet',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Sterge tichet',
    'archived_ticket' => 'Tichet arhivat cu succes',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Tichet sters cu succes',
    'open' => 'Open',
    'new' => 'Nou',
    'closed' => 'Inchis',
    'reopened' => 'Redeschis',
    'priority' => 'Prioritate',
    'last_updated' => 'Last Updated',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Redusa',
    'medium' => 'Medie',
    'high' => 'Ridicata',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Asignare lui',
    'reply' => 'Raspuns',
    'awaiting_reply' => 'In asteptare raspuns',
    'ticket_close' => 'Inchide tichet',
    'ticket_reopen' => 'Redeschide tichet',
    'ticket_open' => 'Deschide tichet',
    'ticket_split' => 'Imparte tichet',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Actualizeaza tichet',
    'ticket_settings' => 'Configuratie tichet',
    'updated_ticket' => 'Tichet actualizat',
    'mark_spam' => 'Marcheaza ca SPAM',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Numele este utilizat deja',
    'local_part_available' => 'Nume disponibil',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Centrul suport clienti',
    'attachments' => 'Atasamente',
    'client_upload' => 'Upload client',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Dimensiune maxima fisier',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'Tichet nou',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Tichet actualizat',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Tichet inchis',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Prioritate implicita',
    'alert_new_comment_id' => 'Comentariu nou',
    'alert_comment_ticket_help' => 'Selectarea unui sablon va trimite o notificare ( agentului ) cand apare un comentariu nou.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Notificare pentru tichete aditionale',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Arată / Ascunde tot',
    'subject_required' => 'Subiect Obligatoriu',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Tichet Părinte',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Selectează Tichet',
    'new_internal_ticket' => 'Adaugă Tichet Intern',
    'internal_ticket' => 'Tichet Intern',
    'create_ticket' => 'Crează Tichet',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compară',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Autentificare Google',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Astăzi',
    'current' => 'Curent',
    'previous' => 'Anterior',
    'current_period' => 'Perioada Curentă',
    'comparison_period' => 'Perioada Comparării',
    'previous_period' => 'Perioada Anterioară',
    'previous_year' => 'Anul Anterior',
    'compare_to' => 'Compară cu',
    'last_week' => 'Săptămâna Trecută',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Ultimele 7 Zile',
    'last30_days' => 'Ultimele 30 Zile',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Vezi detalii produs',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
